class DevicesController < RxModule::ApplicationController
  def self.set_target_before
    super + [:reset]
  end

  model_data_store(Device)
  also_protect_with([
                      RxModule::Authorization.verb("Reset", "Reset", :reset)
                    ])

  include UseComponentName

  def before_set_targets
    Device.joins(:component).preload(component: :connectors) #sub with device classname and the name of the component relationship
  end

  def create
    params = model_params

    @model = Device.new_from_params(params)

    if @model.save
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def bulk_create
    render json: bulk_create_save, status: :ok
  end

  def update
    params = model_params

    Router.instance.synchronize_model(@model) do
      @model.assign_attributes_from_params(params)
      @model.save!
    end

    render :show
  end

  def destroy
    if @model.destroy
      routing_graph = RoutingGraph.first
      routing_graph.remove_node(@model.component[:id])
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def reset
    @model.send_reset
    head :no_content
  end

  private

  def model_params
    params.fetch(:device).permit( :id, :name, :device_type_id, :routing_retry_delay, :delay_on_command_complete, :state, :number_of_outputs, :send_job_state_as, :job_state_process, :always_send_both_job_states)
  end

  def bulk_create_model(device_def)
    OpcuaDevice.new_from_params(device_def)
  end

  def bulk_create_extra_params
    [:name, :device_type_id]
  end
end

