class JobProcessesController < RxModule::ApplicationController
  model_data_store(JobProcess)

  def before_set_targets
    # required to know which side a process exists on
    @models.where(is_control_process: false)
  end

  def update
    Router.instance.synchronize_model(@model) do
      @model.assign_attributes_from_params(update_model_params)

      if @model.tag_condition
        @model.tag_condition.update(condition: condition_params[:condition].to_json)
      else
        @model.build_tag_condition(condition: condition_params[:condition].to_json)
      end

      if @model.save
        render json: @model, status: :ok, location: @model
      else
        render json: @model.errors.full_messages, status: :unprocessable_entity
      end
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  end

  private

  def model_params
    params.fetch(:job_process).permit( :name, :rank, :capability_resolve_mode, :handle_started, :display_name)
  end

  def update_model_params
    params.fetch(:job_process).permit( :name, :rank, :capability_resolve_mode, :handle_started, :display_name, :ignored_abort_reasons_to_add => [:abort_reason])
  end

  def condition_params
    params.fetch(:job_process).permit(condition: {})
  end
end