import * as React from 'react';
import {Layout, Providers} from '@rx-suite/ui';
import {RxAppModel, RxAppStore} from '@rx-suite/stores';
import {getRoutes} from "./routes";
import 'react-table/react-table.css';
import 'react-table-hoc-fixed-columns/lib/styles.css'
import {observer} from "mobx-react-lite";
import {subscribe} from "@rx-suite/data";
import { t } from '@lingui/macro';
import {LinearProgress} from "@material-ui/core";

subscribe();
export default observer(() => {
    const [ messages, setMessages ] = React.useState<any>(null);
    const model = RxAppStore.selectedModel as RxAppModel;

    React.useEffect(() => {
        if (model) {
            const getMessages = async () => {
                const compiledMessages = await import(`../../../locales/${model.language}/messages.mjs`);
                setMessages(compiledMessages.messages);
            }
            model.setTitleBase(t`Rx-Routing`);
            getMessages();
        }
    }, [model]);

    if(!model || !messages) {
        return <LinearProgress />
    }

    return (
        <Providers theme={model.theme} language={model.language} messages={messages}>
            <Layout routes={getRoutes()}/>
        </Providers>
    )
});


