import React from "react";
import {observer} from "mobx-react-lite";
import {
    createStyles,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Grid,
    Theme,
    Typography
} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import {EventModel} from "../../stores/EventStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {makeStyles} from "@material-ui/core/styles";

type EventDetailsDialogProps = {
    model: EventModel | null;
    setModel:  React.Dispatch<React.SetStateAction<EventModel | null>>;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        text: {
            marginLeft: '4px'
        },
        subtitle: {
            fontWeight: 'bold'
        }
    }),
);

export const EventDetailsDialog: React.FunctionComponent<EventDetailsDialogProps> = observer(({model, setModel}) => {
    const classes = useStyles();
    const systemSettings = SystemSettingStore.selectedModel as SystemSettingModel;

    const prettifyDetails = (model: EventModel) => {
        try {
            return JSON.stringify(JSON.parse(model.details), undefined, 4)
        } catch(error) {
            console.error('Event Details are not valid JSON');
            return model.details
        }
    }

    const buildListItem = React.useCallback((title: string, text: string) => {
        return (
            <Grid container>
                <Typography className={classes.subtitle}>{`${title}:`}</Typography>
                <Typography className={classes.text}>{text}</Typography>
            </Grid>
        )
    }, [])

    const closeDialog = React.useCallback(() => {
        setModel(null);
    }, []);

    if(!model) {
        return null;
    }

    return (
        <Dialog open={model != null} onClose={closeDialog} aria-labelledby="form-dialog-title" maxWidth={'md'} fullWidth={true}>
            <DialogTitle id="form-dialog-title">{t`Event Details`}</DialogTitle>
            <DialogContent>
                {buildListItem(t`Event Type`, model.event_type)}
                {buildListItem(t`Time`, systemSettings.printDateTime(model.time))}
                {buildListItem(t`Message`, model.message)}
                <Typography className={classes.subtitle}>{t`Details`}</Typography>
                <Typography style={{whiteSpace: 'pre-wrap'}}>
                    {prettifyDetails(model)}
                </Typography>
                <DialogActions>
                    <ButtonField
                        text={t`Close`}
                        onClick={closeDialog}
                        color={'secondary'}
                        variant={'text'}
                    />
                </DialogActions>
            </DialogContent>
        </Dialog>
    )
})
