import React from "react";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {LmsConfigStore} from "../../stores/LmsConfigStore";
import {System} from "../../hooks/useExternalSystems";
import {ButtonField} from "@rx-suite/ui";

type RouterControlButtonsProps = {
    lmsConfig: System
};

export const LmsReinitializeButton: React.FunctionComponent<RouterControlButtonsProps> = ({ lmsConfig }) => {
    const {enqueueSnackbar} = useSnackbar();
    const [isReinitialising, setIsReinitialising] = React.useState(false);

    const reinitializeConnection = async () => {
        setIsReinitialising(true);

        try {
            const resp = await LmsConfigStore.transportLayer.fetch(`/${lmsConfig.lms_config_id}/reinitialize`, {method: "POST"});
            const data = await resp.json();

            if(data.online) {
                enqueueSnackbar(`${t`LMS successfully initialised.`}`, {variant: "success"});
            } else {
                enqueueSnackbar(`${t`Failed to initialise LMS connection.`}`, {variant: "error"});
            }
        }catch(err){
            console.error(err);
            enqueueSnackbar(`${t`Error while resetting LMS connection`}`, {variant: "error"});
        }

        setIsReinitialising(false);
    }

    return (
        <ButtonField
            text={(lmsConfig.online ?  t`Reinitialise` :  t`Initialise`)}
            color={'secondary'}
            variant={'contained'}
            onClick={async () => await reinitializeConnection()}
            loading={isReinitialising}
            size={'small'}
        />
    )
};