import * as React from "react";
import {makeStyles} from "@material-ui/core/styles";
import {Box, createStyles, Grid, Theme, Typography} from "@material-ui/core";
import { useModelContext } from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {faCheckCircle, faDotCircle, faExclamationCircle} from "@rx-suite/pro-solid-svg-icons";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import classNames from "classnames";
import {green, grey, orange, red} from "@material-ui/core/colors";
import {RouterServerModel} from "../../stores/RouterServerStore";
import {observer} from "mobx-react-lite";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        header: {
            fontWeight: 'bold',
            fontSize: '1.5rem',
            color: grey[700]
        },
        statusText: {
            fontSize: '2.25rem',
            fontWeight: 'bold'
        },
        icon: {
            fontSize: '1.45rem'
        },
        grey: {
            color: grey[500]
        },
        yellow: {
            color: orange[500]
        },
        green: {
            color: green[500]
        },
        red: {
            color: red[500]
        }
    })
);

export const RouterStatusIndicator: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const router = useModelContext() as RouterServerModel;

    const status = React.useMemo(  () => {
        switch(router.status){
            case "offline":
                return {
                    text: t`Offline`,
                    icon: faDotCircle,
                    color: classes.grey
                }
            case "starting":
                return {
                    text: t`Starting`,
                    icon: faDotCircle,
                    color: classes.yellow
                }
            case "online":
                return {
                    text: t`Online`,
                    icon: faCheckCircle,
                    color: classes.green
                }
            case "standby":
                return {
                    text: t`Standby`,
                    icon: faExclamationCircle,
                    color: classes.yellow
                }
            case "error":
                return {
                    text: t`Error`,
                    icon: faExclamationCircle,
                    color: classes.red
                }
        }
    }, [router.status]);

    return (
        <React.Fragment>
            <Box>
                <Typography className={classes.header}>{t`Router Status`}</Typography>
            </Box>
            <Grid container alignItems={'center'}>
                <Box mr={1}>
                    <FontAwesomeIcon icon={status.icon} className={classNames(classes.icon, status.color)}/>
                </Box>
                <Typography className={classNames(classes.statusText, status.color)}>{status.text}</Typography>
            </Grid>
        </React.Fragment>
    );
});



