import React from "react";
import {ModelSelect} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {HintList} from "../../generic/HintList";
import {t} from "@lingui/macro";
import {useRouterOnline} from "../../../hooks/useRouterOnline";

export const ConnectorStateSelect: React.FunctionComponent = observer(() => {
    const options =  [
        {label: t`online`, value: 'online'},
        {label: t`standby`, value: 'standby'},
        {label: t`offline`, value: 'offline'}
    ]

    const connectorStateHint = [
        {title: t`online`, text: t`Jobs arrive at this connector will be routed.`},
        {title: t`standby`, text: t`Jobs arriving at this input will not be routed, however, the connector will still be used in the routing graph.`},
        {title: t`offline`, text: t`Jobs arriving at this input will not be routed and this connector will be disconnected from the routing graph. `}
    ];

    return (
        <ModelSelect name={'state'}
                     options={options}
                     hint={ {
                         title: 'Connector State',
                         children: <HintList
                             primaryText={t`Determines how this connector is used.`}
                             items={connectorStateHint}
                         />
                     }}
                     disabled={useRouterOnline()}
        />
    )
});