import React from "react";
import {ModelProvider, useModelContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ConnectorModel} from "../../../../stores/ConnectorStore";
import {Box, Divider, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ControlActionJobStartForm} from "./actions/ControlActionJobStartForm";
import {ControlActionModifyJobDataForm} from "./actions/ControlActionModifyJobDataForm";
import {ControlActionRoutingOverridesForm} from "./actions/ControlActionRoutingOverridesForm";
import {ControlActionValidateJobDataForm} from "./actions/ControlActionValidateJobDataForm";
import {SettingModel, SettingStore} from "../../../../stores/SettingStore";

export const ConnectorControlActionForm: React.FunctionComponent = observer(() => {
    const model = useModelContext() as ConnectorModel;
    const settings = SettingStore.selectedModel as SettingModel;

    return (
        <ModelProvider value={model}>
            <Box mt={2} mb={2}>
                <Divider/>
                <Typography variant={'h6'}>{t`Control Actions`}</Typography>
                <Box ml={1.5}>
                    <ControlActionJobStartForm/>
                    <ControlActionModifyJobDataForm/>
                    <ControlActionRoutingOverridesForm/>
                    {settings.routingModeIsFinishing && <ControlActionValidateJobDataForm/>}
                </Box>
            </Box>
        </ModelProvider>
    )
});