import React from "react";
import {Conditional, HintButton, ModelCheckbox, useModelContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, Grid, makeStyles, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {HintList} from "../../../../generic/HintList";
import {ConnectorModel} from "../../../../../stores/ConnectorStore";

const useStyles = makeStyles((theme) => ({
     sectionHeader: {
         fontSize: '1.15rem',
         fontWeight: 'bold'
     }
 }))

export const ControlActionJobStartForm: React.FunctionComponent = observer(() => {
    const model = useModelContext() as ConnectorModel;
    const classes = useStyles();

    const jobsStartHint =  [
        {title: t`Restart Existing Jobs`, text: t`Existing jobs at this input will be recalculated and treated as new jobs.`}
    ];

    return (
        <React.Fragment>
            <Box mb={-1.5}>
                <Grid container alignItems={'center'}>
                    <Typography className={classes.sectionHeader}>{t`Allow Job Start`}</Typography>
                    <HintButton
                        title={t`Allow Job Start`}
                        children={<HintList
                            primaryText={t`Allows jobs to be started at this input.`}
                            items={jobsStartHint}/>
                        }
                    />
                </Grid>
            </Box>
            <Box>
                <ModelCheckbox label={t`Enabled`}
                               name={'control_action_config.fetch.enabled'}
                               onChange={(e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
                                       model.handleChange(e);
                                       if(!model.fetchEnabled){
                                           model.nestedAssignment('control_action_config.fetch.restart', false);
                                       }
                                   }
                               }
                />
            </Box>
            <Conditional condition={model.fetchEnabled}>
                <Box ml={2.5} mt={-1.5}>
                    <ModelCheckbox label={t`Restart Existing Jobs`} name={'control_action_config.fetch.restart'}/>
                </Box>
            </Conditional>
        </React.Fragment>
    )
});