import React from "react";
import {HintButton, ModelCheckbox} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, Grid, makeStyles, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {HintList} from "../../../../generic/HintList";


const useStyles = makeStyles((theme) => ({
     sectionHeader: {
         fontSize: '1.15rem',
         fontWeight: 'bold'
     }
 }))

export const ControlActionRoutingOverridesForm: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const routingOverrideHints =  [
        {title: t`Hold 'started' Jobs`, text: t`Jobs with the next process in the state 'started' will hold at the input.`},
        {title: t`Hold 'rejected' Jobs`, text: t`Jobs that are rejected will will hold at the input.`},
        {title: t`Balance jobs to output`, text: t`Jobs that arrive at this device will be split amongst the outputs as much as possible.`},
        {title: t`Full Path Resolve`, text: t`Forces the routing logic to only consider paths with the entire process chain required by a job to be valid.`},
    ];

    return (
        <React.Fragment>
            <Box mb={-1.5}>
                <Grid container alignItems={'center'}>
                    <Typography className={classes.sectionHeader}>{t`Routing Overrides`}</Typography>
                    <HintButton
                        title={t`Routing Overrides`}
                        children={<HintList
                            primaryText={t`Modifies the basic routing behavior of the input.`}
                            items={routingOverrideHints}/>
                        }
                    />
                </Grid>
            </Box>
            <Box>
                <ModelCheckbox label={t`Hold 'started' Jobs`} name={'control_action_config.holdStarted'}/>
            </Box>
            <Box>
                <ModelCheckbox label={t`Hold 'rejected' jobs`} name={'control_action_config.holdReject'}/>
            </Box>
            <Box>
                <ModelCheckbox label={t`Balance jobs to outputs`} name={'control_action_config.splitJobsToOutput'}/>
            </Box>
            <Box>
                <ModelCheckbox label={t`Force Full Path Resolve`} name={'control_action_config.forceFullPathResolve'}/>
            </Box>
        </React.Fragment>
    )
});