import React from "react";
import {Conditional, HintButton, ModelCheckbox, ModelSelect, useModelContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, Grid, makeStyles, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {HintList} from "../../../../generic/HintList";
import {ConnectorModel} from "../../../../../stores/ConnectorStore";
import {useProcessSelectByName} from "../../../../../hooks/useProcessSelectByName";

const useStyles = makeStyles((theme) => ({
     sectionHeader: {
         fontSize: '1.15rem',
         fontWeight: 'bold'
     }
 }))

export const ControlActionValidateJobDataForm: React.FunctionComponent = observer(() => {
    const model = useModelContext() as ConnectorModel;
    const classes = useStyles();

    const validateJobsHint =  [
        {title: t`Process to Validate`, text: t`If the selected process is not completed a reject will be triggered.`},
    ];

    const forceToProcessHint =  [
        {title: t`Ensure No Prior Aborts`, text: t`Any aborted processes prior to the selected process will trigger a reject.`},
        {title: t`Ensure All Prior Completed`, text: t`Any non completed processes before the selected will trigger a reject.`}
    ];

    return (
        <React.Fragment>
            <Box mb={-1.5}>
                <Grid container alignItems={'center'}>
                    <Typography className={classes.sectionHeader}>{t`Validate Job Data`}</Typography>
                    <HintButton
                        title={t`Validate Job Data`}
                        children={<HintList
                            primaryText={t`Allows the input to validate the job data.`}
                            items={validateJobsHint}/>
                        }
                    />
                </Grid>
            </Box>
            <Box>
                <ModelSelect
                    name={'control_action_config.validateProcesses.process'}
                    label={'Process to Validate'}
                    options={useProcessSelectByName()}
                    hint={
                        {
                            title: t`Process to Validate`,
                            children: <HintList items={forceToProcessHint}/>
                        }
                    }
                />
                <Conditional condition={model.validateProcessesEnabled}>
                    <Box ml={1.75}>
                        <Box mt={-0.5}>
                            <ModelCheckbox label={t`Ensure No Prior Aborts`} name={'control_action_config.validateProcesses.ensureNoPriorAbort'}/>
                        </Box>
                        <Box mt={-1.5}>
                            <ModelCheckbox label={t`Ensure All Prior Completed`} name={'control_action_config.validateProcesses.ensurePriorCompleted'}/>
                        </Box>
                    </Box>
                </Conditional>
            </Box>
        </React.Fragment>
    )
});