import React from "react";
import {observer} from "mobx-react-lite";
import {DeviceModel} from "../../../stores/Device/DeviceStore";
import {Conditional, ModelCheckbox, ModelInput, ModelSubmitButton, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export const DeviceDataTrackingTab: React.FunctionComponent = observer(() => {
    const model = useModelContext() as DeviceModel;

    return (
        <React.Fragment>
            <ModelCheckbox
                name={'send_job_state'}
                hint={
                    {
                        title: t`Send Job State when job arrive at this decision point`,
                        text: t`When a job arrives at this decision point, a job state will be recorded. This can be used to record throughput on segments of the line, such as launch volume.`
                    }
                }
            />
            <Conditional condition={model.viewModel.send_job_state}>
                <ModelInput name={'send_job_state_as'}
                            hint={
                                {
                                    title: t`Send Job State As`,
                                    text: t`This will be used as the SN of the machine when the job state is sent.`
                                }
                            }
                            error={model.viewModel.send_job_state_as === null || model.viewModel.send_job_state_as.trim() === ''}
                />
                <ModelInput name={'job_state_process'}
                            hint={
                                {
                                    title: t`Job State Process`,
                                    text: t`This will be as the process of the machine when the job state is sent`
                                }
                            }
                            error={model.viewModel.job_state_process === null || model.viewModel.job_state_process.trim() === ''}
                />
                <ModelCheckbox
                    name={'always_send_both_job_states'}
                />
            </Conditional>
            <ModelSubmitButton/>
        </React.Fragment>
    )
})