import React from "react";
import { t } from "@lingui/macro";
import {useModelContext} from "@rx-suite/ui";
import {DeviceModel, DeviceStore} from "../../../stores/Device/DeviceStore";
import {ModelActionButton} from "../../generic/ModelActionButton";
import {currentUserCan} from "@rx-suite/stores";
import {useRouterOnline} from "../../../hooks/useRouterOnline";
import {ExclamationCircleOutlined} from "@ant-design/icons";

export const OpcuaDeviceResetButton: React.FunctionComponent = () => {
    const model = useModelContext() as DeviceModel;

    if(model.isNew || !currentUserCan((DeviceStore.permissionTarget as string), 'reset')){
        return null;
    }

    const routerOnline = useRouterOnline();

    const style = React.useMemo(() => {
        if(!routerOnline){
            return undefined;
        }

        return {backgroundColor: 'rgb(244,67,54)'};
    }, [routerOnline])


    return (
        <ModelActionButton
            name={'requestPlcReset'}
            text={t`Request PLC Reset`}
            startIcon={<ExclamationCircleOutlined/>}
            style={style}
            disabled={!useRouterOnline()}

        />
    )
}