import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t, Trans} from '@lingui/macro';
import {ButtonField, InputField, PaddedPaper} from "@rx-suite/ui";
import {Box, Grid, makeStyles, Typography} from "@material-ui/core";
import {ImportExport} from "@material-ui/icons";
import {grey} from "@material-ui/core/colors";
import {SyntheticEvent} from "react";
import {useSnackbar} from "notistack";
import {FetchedJobData} from "../../pages/fetched_jobs/FetchedJobForm";

const useStyles = makeStyles((theme) => ({
    searchBox: {
        width: '90%'
    },
    dataSourceLabel: {
        fontSize: '1rem',
        color: grey[500],
        marginBottom: theme.spacing(2)
    },
    text: {
        color: grey[700]
    },
    icon: {
        color: grey[700],
        marginRight: theme.spacing(1)
    }
}));

export const FetchJobSearchField: React.FunctionComponent<FetchJobSearchFieldProps> = observer(({setDataHandler}) => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const [searchFieldValue, setSearchFieldValue] = React.useState<string>("");
    const [isFetching, setIsFetching] = React.useState(false);

    const handleSubmit = React.useCallback(async (e: SyntheticEvent) => {
        e.preventDefault();

        if(searchFieldValue === ""){
            return;
        }

        setIsFetching(true);
        setDataHandler(null);

        const resp = await fetch(`/api/orders/search_data/${searchFieldValue}`, {
            method: "GET",
            headers: {'Content-Type': 'application/json'}
        })

        const content = await resp.json();
        setSearchFieldValue("");
        if(!resp.ok){
            const error = content.error ? content.error : "Unknown Error";
            enqueueSnackbar(<>{error}</>, {variant: "error"});
        }else{
            setDataHandler(content as FetchedJobData);
            enqueueSnackbar(<Trans>Job data found.</Trans>, {variant: "success"});
        }

        setIsFetching(false);
    }, [searchFieldValue]);

    const handleChange = (e) => {
        setSearchFieldValue(e.target.value)
    }

    return (
        <Box mb={1}>
            <PaddedPaper >
                <Grid container alignItems={'center'}>
                    <ImportExport className={classes.icon}/>
                    <Typography variant={'h5'}  className={classes.text}><Trans>Test Job Processes</Trans></Typography>
                </Grid>
                <form onSubmit={handleSubmit}>
                    <Grid container justifyContent="space-evenly">
                        <InputField label={t`Job Number`} className={classes.searchBox} value={searchFieldValue} onChange={handleChange} autoFocus/>
                        <ButtonField text={t`Search`} buttonType='submit' color='secondary' variant='contained' loading={isFetching}/>
                    </Grid>
                </form>
            </PaddedPaper>
        </Box>
    )
});

type FetchJobSearchFieldProps = {
    setDataHandler:  React.Dispatch<React.SetStateAction<FetchedJobData | null>>;
}