import React from "react";
import {observer} from "mobx-react-lite";
import {Grid} from "@material-ui/core";
import ReactTable from "react-table";
import {t} from "@lingui/macro";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";

type ProcessInfoTableTableProps = {
    processes: JobFetchProcessInfo[]
}

export const ProcessInfoTable: React.FunctionComponent<ProcessInfoTableTableProps> = observer(({processes}) => {
    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const displayRightLensFirst = systemSettingModel?.displayRightLensFirst();

    const makeCol = React.useCallback((side: string) => {
        return [
            {
                Header: t`Processes` + ' (' + `${side}` + ')',
                columns: [
                    {Header: t`Name`, accessor: 'name'},
                    {
                        Header: t`Capabilities`,
                        id: 'capabilities',
                        accessor: (data: JobFetchProcessInfo) => data,
                        Cell: (cellInfo: { value: JobFetchProcessInfo }) => {
                            return cellInfo.value.capabilities.join(', ');
                        }
                    },
                ]
            }
        ]
    }, [])

    const leftProcesses = processes.filter(process => process.side === 'left');
    const rightProcesses = processes.filter(process => process.side === 'right');
    const pageSize = leftProcesses.length > rightProcesses.length ? leftProcesses.length : rightProcesses.length;

    return (
        <Grid container direction={displayRightLensFirst ? 'row' : 'row-reverse'}>
            <Grid item xs={6}>
                <ReactTable
                    data={rightProcesses}
                    columns={makeCol('Right')}
                    defaultPageSize={pageSize}
                    showPaginationBottom={false}
                />
            </Grid>
            <Grid item xs={6}>
                <ReactTable
                    data={leftProcesses}
                    columns={makeCol('Left')}
                    defaultPageSize={pageSize}
                    showPaginationBottom={false}
                />
            </Grid>
        </Grid>
    )
})

export type JobFetchProcessInfo = {
    name: string;
    capabilities: string[];
    rank: number;
    side: 'left' | 'right'
}