import * as React from "react";
import {observer} from "mobx-react-lite";
import {useSnackbar} from "notistack";
import {ButtonField, useModelContext} from "@rx-suite/ui";
import {ButtonFieldProps} from "@rx-suite/ui/lib/components/base/ButtonField";

type ModelActionButtonProps = {
    name: string;
} & ButtonFieldProps;

export const ModelActionButton: React.FunctionComponent<ModelActionButtonProps> = observer(({name, ...props}) => {
    const {enqueueSnackbar} = useSnackbar();
    const model = useModelContext();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    const invokeAction = React.useCallback(async () => {
        setIsLoading(true);

        try {
            await (model[name] as () => void)();
            enqueueSnackbar(`'${props.text}' successful.`, { variant: 'success' });
        }catch (e) {
            console.error(e);
            enqueueSnackbar(`An issue occurred with '${props.text}'`, { variant: 'error' });
        }

        setIsLoading(false);
    }, [model, name, props.text]);

    return <ButtonField
        text={props.text}
        onClick={async () => { await invokeAction(); }}
        loading={isLoading}
        {...props}
       />
})