import React from "react";
import {ButtonField, ModelProvider} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {Model} from "@rx-suite/data";

type ModelFormDialogProps = {
    title: string;
    model: Model;
    setModel: React.Dispatch<React.SetStateAction<Model | null>>
}

export const ModelFormDialog: React.FunctionComponent<ModelFormDialogProps> = observer(({title, model, setModel, children}) => {
    const {enqueueSnackbar} = useSnackbar();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    const handleClose = React.useCallback(() => {
        model.viewModel.resetView();
        setModel(null);
    }, [setModel])

    const handleSubmit = React.useCallback(async () => {
        setIsLoading(true);

        try{
            await model.commit()
            enqueueSnackbar(t`Successfully Updated`, {variant: "success"});
            setModel(null);
        }catch (e) {
            console.error(e);
            setIsLoading(false);
            enqueueSnackbar(t`Error Saving`, {variant: "error"});
        }
    }, [model])

    return(
        <ModelProvider value={model}>
            <Dialog open={true} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={"md"} fullWidth={true}>
                <DialogTitle id="form-dialog-title">{title}</DialogTitle>
                <DialogContent>
                    {children}
                    <DialogActions>
                        <ButtonField
                            text={t`Close`}
                            onClick={handleClose}
                            color={'secondary'}
                            variant={'outlined'}
                        />
                        <ButtonField
                            text={t`Submit`}
                            onClick={handleSubmit}
                            loading={isLoading}
                            color={'secondary'}
                            disabled={!model.viewModel.isValid}
                        />
                    </DialogActions>
                </DialogContent>
            </Dialog>
        </ModelProvider>
    )
});