import React from "react";
import {useSnackbar} from "notistack";
import {createStyles, Switch, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";
import {SwitchProps} from "@material-ui/core/Switch/Switch";

type EnabledSwitchProps = {
    model: Model;
    success: string;
    failure: string,
    noSnackBar?: boolean
} & SwitchProps;

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        switch: {
            "& .MuiIconButton-root" : {
                padding: '9px',
            }
        }
    })
);

export const ModelToggleSwitch: React.FunctionComponent<EnabledSwitchProps> = observer(({ model , success, failure, noSnackBar=false, ...props}) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles()

    const handleChange = React.useCallback( async () => {
        const resp = await model.toggle();

        if(noSnackBar) { return; }

        if(resp.status === 200) {
            enqueueSnackbar(success, {variant: "success"});
        } else {
            enqueueSnackbar(failure, {variant: "error"});
        }
    }, [])

    return (
        <Switch
            className={classes.switch}
            checked={model.enabled as boolean}
            color={'secondary'}
            onChange={handleChange}
            {...props}
        />
    )
})