import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {
    AssociatedModelTable,
    makeColumn,
    ModelSelect,
    useModelContext
} from "@rx-suite/ui";
import {HintList} from "../../generic/HintList";
import {IgnoredAbortReasonStore} from "../../../stores/IgnoredAbortReasonStore";
import {Box, Typography} from "@material-ui/core";
import {AbortReasonDialogComponent} from "../routing_settings_tab/AbortReasonDialogComponent";

type JobProcessOtherSettingsTab = { }

export const JobProcessRoutingSettingsTab: React.FunctionComponent<JobProcessOtherSettingsTab> = observer(() => {
    const model = useModelContext();

    const capabilityResolveOptions = [
        {label: t`Require All`, value: 'require_all'},
        {label: t`Require Highest Rank`, value: 'highest_rank'}
    ];

    const capabilityResolveHints = [
        {title: t`Require All`, text: t`All the capabilities that pass the condition will be required.`},
        {title: t`Require Highest Rank`, text: t`Only the highest ranked capability between both eyes will be required.`}
    ];

    const handleStartedOptions = [
        {label: t`Reject Job`, value: 'reject_job'},
        {label: t`Hold as Not Started`, value: 'hold_as_current'},
        {label: t`Hold as Finished`, value: 'hold_as_next'}
    ];

    const handleStartedHints = [
        {title: t`Reject Job`, text: `The job will be rejected and head for the nearest kickout.`},
        {title: t`Hold as Not Started`, text: `The job will stay on the line at the current process step. (i.e: a job in 'started' blocking will stay in a blocker loop).`},
        {title: t`Hold as Finished`, text: `The job will stay on the line at the next process step (i.e: a job in 'started' blocking will go to a generator loop).`}
    ];

    const abortReasonColumns = React.useMemo(() => {
        return [
            makeColumn('abort_reason', t`Abort Reason`, 'string')
        ]
    }, []);

    return (
        <React.Fragment>
            <ModelSelect
                name={'handle_started'}
                options={handleStartedOptions}
                hint={
                    {
                        title: 'Handle Started',
                        children: <HintList
                            primaryText={t`Determines how this process is handled when a job is at a decision point in the started state.`}
                            items={handleStartedHints}
                        />
                    }
                }
            />
            <ModelSelect
                name={'capability_resolve_mode'}
                options={capabilityResolveOptions}
                hint={
                        {
                            title: 'Resolve Capabilities',
                            children: <HintList
                                            primaryText={t`Determines how capabilities are calculated for a given job.`}
                                            items={capabilityResolveHints}
                                        />
                        }
                    }
            />
            <Box mt={2} display={'flex'} flexDirection={'column'}>
                <Typography variant={'h6'}>{t`Abort Reasons to Treat as finished`}</Typography>
                <AssociatedModelTable
                    suppressWrapper
                    baseModel={model}
                    associatedColumnName={'ignored_abort_reasons_to_add'}
                    columns={abortReasonColumns}
                    noLinkColumns={['abort_reason']}
                    DialogForm={AbortReasonDialogComponent}
                    store={IgnoredAbortReasonStore}
                    defaultFiltered={[{id: 'job_process_id', value: model.getId(), strictMatchFilter: true}]}
                    replacementActions={
                        {
                            Read: () => null,
                            Edit: () => null
                        }
                    }
                />
            </Box>
        </React.Fragment>
    );
});
