import React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, FormProps, IfTrue, ModelInput, ModelProvider} from "@rx-suite/ui";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {Model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import {JobProcessModel} from "../../stores/machine/JobProcessStore";

interface CapabilityDialogProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void
    process: JobProcessModel;
}

export const CapabilityDialogComponent: React.FunctionComponent<CapabilityDialogProps> = observer(({model, process, open, handleSubmit, handleClose}) => {

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title">
                    <DialogTitle id="form-dialog-title">Add Capability</DialogTitle>
                    <DialogContent>
                        <ModelInput name={'name'}/>
                        <ModelInput name={'display_name'} hint={{title: t`Display Name Usage`, text: t`This will be displayed instead of the name.`}}/>
                        <Conditional condition={process.requireCapabilityRank}>
                            <IfTrue>
                                <ModelInput name={'rank'}/>
                            </IfTrue>
                        </Conditional>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>
                                close
                            </Button>
                            <Button
                                disabled={!model.viewModel.isValid || (process.requireCapabilityRank && model.viewModel.rank === null)}
                                onClick={e => handleSubmit(model)}
                                color={"secondary"}
                            >
                                Submit
                            </Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
