import React, {useContext, useMemo} from "react";
import {observer} from "mobx-react-lite";
import {CheckboxField, ModelSelect, useModelContext} from "@rx-suite/ui";
import {MesMachineStateModel, MesMachineStateStore, StateObject} from "../../stores/machine/MesMachineStateStore";
import {MachineContext} from "../../pages/machines/MachineFormRouter";

export const MesMachineStateDialogComponent: React.FunctionComponent = observer(({}) => {
    const model = useModelContext() as MesMachineStateModel;
    const machineModel = useContext(MachineContext);

    const handleCheckBoxChange = React.useCallback((field: string, value:string) => {
        model.nestedAssignment('online', value);
    }, []);

    const stateOptions = useMemo(() => {
        if(!machineModel) { return []; }

        const tempStates = machineModel.viewModel.mes_machine_states_to_add.map((state) => state.name);
        return StateObject.filter(
            (stateName) => !MesMachineStateStore.models.map(
                (m) => m.name
            ).includes(stateName) && !tempStates.includes(stateName)
        ).map((state) => ({label: state, value: state}))
    }, [StateObject, MesMachineStateStore.models, machineModel?.viewModel.mes_machine_states_to_add])

    return (
        <React.Fragment>
            <ModelSelect name={'name'} options={stateOptions}/>
            <CheckboxField label={'Online state?'} onChange={handleCheckBoxChange} checked={model.viewModel.online}/>
        </React.Fragment>
    )
});
