import React from "react";
import {createStyles, Grid, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {observer} from "mobx-react-lite";
import classNames from "classnames";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCheck, faTimes} from "@rx-suite/pro-solid-svg-icons";
import {green, grey, red} from "@material-ui/core/colors";
import {CapabilityMachineModel} from "../../../stores/machine/CapabilityMachineStore";
import {CapabilityStore} from "../../../stores/machine/CapabilityStore";

interface MachineCapabilityBadgeProps {
    machineCapability: CapabilityMachineModel;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        badge: {
            width: 'max-content',
            margin: '1px',
            padding: '1px 6px',
            borderRadius: '3px',
            backgroundColor: grey[300]
        },
        icon: {
            fontSize: '14px'
        },
        label: {
            fontSize: '14px',
            paddingLeft: '2px',
        },
        disabled: {
            color: red[600]
        },
        enabled: {
            color: green[600],
        }
    })
);

export const MachineCapabilityBadge: React.FunctionComponent<MachineCapabilityBadgeProps> = observer(({ machineCapability}) => {
    const classes = useStyles();

    const capability = React.useMemo(() => {
        return CapabilityStore.models.find(capability => machineCapability.capability_id == capability.id);
    }, [machineCapability, CapabilityStore.models])

    const icon = React.useMemo(()=>{
        if(machineCapability.enabled){
            return faCheck;
        }else{
            return faTimes;
        }
    }, [machineCapability]);

    const styleClass = React.useMemo(()=>{
        if(machineCapability.enabled){
            return classes.enabled;
        }else{
            return classes.disabled;
        }
    }, [machineCapability]);

    if(!capability){
        return null;
    }

    return (
        <Grid item container className={classes.badge} alignItems={'center'}>
            <FontAwesomeIcon icon={icon} size={'1x'} className={classNames(classes.icon, styleClass)}/>
            <Typography variant={'subtitle2'} className={classNames(classes.label, styleClass)}>{capability.resolvedName}</Typography>
        </Grid>
    )
})