import React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {crossModuleLink, currentUserCan} from "@rx-suite/stores";
import {Box, Grid, Typography} from "@material-ui/core";
import {InfoRounded} from "@material-ui/icons";
import {makeStyles} from "@material-ui/core/styles";
import {grey} from "@material-ui/core/colors";

const useStyles = makeStyles(theme => ({
    icon: {
        fontSize: '1rem',
        color: grey[600]
    },
    hintText: {
        color: grey[600]
    }
}));

export const MesMachineCreateButton: React.FunctionComponent= observer(() => {
    const classes = useStyles();
    const linkToRxDataMachines = crossModuleLink('rx_data', '/settings/machines');

    if(!currentUserCan('machine', 'create')){
        return null;
    }

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    return (
        <Box>
            <Grid container direction={'column'}>
                <Box mb={-1}>
                    <ButtonField
                        text={'Create'}
                        component={'a'}
                        variant={'contained'}
                        color={'secondary'}
                        href={linkToRxDataMachines}
                        onClick={() => setIsLoading(true)}
                        loading={isLoading}
                    />
                </Box>
                <Box ml={1} mt={0.5}>
                    <Grid container>
                        <Box mr={0.25}>
                            <InfoRounded className={classes.icon}/>
                        </Box>
                        <Typography className={classes.hintText} variant={'caption'}>{t`Machines are created in Rx-Data and are automatically synchronized`}</Typography>
                    </Grid>
                </Box>
            </Grid>
        </Box>
    )
})