import {observer} from "mobx-react-lite";
import React, {useCallback, useContext, useMemo} from "react";
import {CapabilitiesModel, CapabilityStore} from "../../../stores/machine/CapabilityStore";
import {SelectField, useModelContext} from "@rx-suite/ui";
import {CapabilityMachineModel, CapabilityMachineStore} from "../../../stores/machine/CapabilityMachineStore";
import {MachineContext} from "../../../pages/machines/MachineFormRouter";

export const MachineCapabilityDialog: React.FunctionComponent = observer(({}) => {
    const model = useModelContext() as CapabilityMachineModel;
    const machineModel = useContext(MachineContext);

    const getPossibleCapabilitiesOptions = useMemo(() => {
        if(!machineModel) { return []; }

        // Filter out models loaded in the CapabilityMachineStore, since those are the ones loaded in the table and
        // therefore belong to the current machine. Also remove capabilities that are going to be added
        const tempCapabilities = machineModel.viewModel.capabilities_to_add.map((cap) => cap.capability_id);
        const filtered = CapabilityStore.models.filter((capability: CapabilitiesModel) => {
            return !CapabilityMachineStore.tableIDs.includes(capability.getId()) && !tempCapabilities.includes(capability.getId())
        })
        return filtered.map((capability: CapabilitiesModel) => ({label: capability.name, value: capability.id}))
    }, [CapabilityStore.models, CapabilityMachineStore.tableIDs, machineModel?.viewModel.capabilities_to_add])

    const onChange = useCallback((name, value) => {
        const capability = CapabilityStore.get(value);
        model.nestedAssignment('capability_name', capability?.name);
        model.nestedAssignment('capability_id', value);
    }, [CapabilityStore.models])

    return (
        <SelectField
            value={model.viewModel.dig('capability_id')}
            onChange={onChange}
            options={getPossibleCapabilitiesOptions}
        />
    )
})
