import React from "react";
import {createStyles, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {observer} from "mobx-react-lite";
import {currentUserCanPermission} from "@rx-suite/stores";
import {MachineModel, MachineStore} from "../../../stores/machine/MachineStore";
import {t} from "@lingui/macro";
import {ButtonField, useFlag, useModelContext} from "@rx-suite/ui";
import {red} from "@material-ui/core/colors";
import {useSnackbar} from "notistack";
import { useRouterOnline } from "../../../hooks/useRouterOnline";
import { useHistory } from 'react-router-dom';
import {WarningDialog} from "../../generic/WarningDialog";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        danger: {
            color: red[300],
            borderColor: red[300],
            '&:hover': {
                borderColor: red[300]
            }
        }
    })
);

export const SetMachineVirtualButton: React.FunctionComponent = observer(({}) => {
    const classes = useStyles()
    const {enqueueSnackbar} = useSnackbar();
    const history = useHistory();
    const model = useModelContext() as MachineModel;

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    const [open, setOpenTrue, setOpenFalse, toggleOpen] = useFlag(false);

    const handleSetMachineVirtual = React.useCallback(async () => {
        setOpenFalse();

        setIsLoading(true);

        try {
            const resp = await model.setMachineVirtual();
            history.push(`/special_processes/${model.getId()}/edit`);
        } catch (e) {
            console.error(e);
            enqueueSnackbar(t`Failed to change machine type`, { variant: 'error' });
        }

        setIsLoading(false);
    }, [model]);
    
    const canSetMachineVirtual = currentUserCanPermission({
        target: MachineStore.permissionTarget as string,
        action: 'OverwriteType'
    });

    if (!canSetMachineVirtual) {
        return null;
    }

    return <>
        <ButtonField
            text={t`Set as Virtual Machine`}
            variant={'outlined'}
            onClick={setOpenTrue}
            loading={isLoading}
            disabled={useRouterOnline()}
            className={classes.danger}
        />
        <WarningDialog
            warningMessage={t`This will move this machine to the special processes menu and several settings will be unavailable.`}
            open={open}
            onConfirm={handleSetMachineVirtual}
            handleClose={setOpenFalse}
            critical
        />
    </>;
})