import React, {useEffect} from "react";
import {observer} from "mobx-react-lite";
import {Box, LinearProgress} from "@material-ui/core";
import {OrderModel} from "../../stores/OrderStore";
import {OrderRejectBanner} from "./order_info_components/OrderRejectBanner";
import {OrderActionsBar} from "./order_info_components/OrderActionsBar";
import {OrderProcessesTable} from "./order_info_components/OrderProcessesTable";
import {ModelProvider} from "@rx-suite/ui";
import {JobProcessStore} from "../../stores/machine/JobProcessStore";
import { IsSubmittingProvider } from "../../hooks/useIsSubmitting";
import {OrderStatusBanner} from "./order_info_components/OrderStatusBanner";
import {RequiredProcessesProvider} from "../../hooks/useRequiredProcesses";
import {useRequiredProcessClonedStore} from "../../hooks/useRequiredProcessClonedStore";

type OrderInfoProps = {
    model: OrderModel;
};

export const OrderInfo: React.FunctionComponent<OrderInfoProps> = observer(({model}) => {
    const [isSubmitting, setIsSubmitting] = React.useState<boolean>(false);

    const [requiredProcessClonedStore, fetching, refreshClonedStore] = useRequiredProcessClonedStore(model.required_process_ids);

    useEffect(() => {
        refreshClonedStore(model.required_process_ids);

        // NOTE: Arrays are references, stringify to detect a change IN the array, and not the array itself
    }, [JSON.stringify(model.required_process_ids)]);

    if(JobProcessStore.isLoading || requiredProcessClonedStore.isLoading || fetching){
        return <LinearProgress/>;
    }

    return <ModelProvider value={model}>
        <RequiredProcessesProvider value={{
            requiredProcesses: requiredProcessClonedStore.models,
            refreshRequiredProcesses: (required_process_ids: number[]) => { refreshClonedStore(required_process_ids); }
        }}>
            <IsSubmittingProvider value={{ isSubmitting, setIsSubmitting }}>
                <Box display={'flex'} flexDirection={'column'}>
                    <OrderStatusBanner/>
                    {model.reject_reason && <Box mb={2}>
                        <OrderRejectBanner rejectInfo={{reason: model.reject_reason, description: model.rejectDescription()}}/>
                    </Box>}
                    <Box mb={1}>
                        <OrderActionsBar/>
                    </Box>
                    <Box>
                        <OrderProcessesTable/>
                    </Box>
                </Box>
            </IsSubmittingProvider>
        </RequiredProcessesProvider>
    </ModelProvider>;
});
