import React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Theme, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {grey} from "@material-ui/core/colors";
import {JobSide} from "../../../stores/RequiredProcessStore";

type LensNumberDisplayProps = {
    jobNumber: string;
    side: JobSide;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        headerText: {
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            whiteSpace: 'nowrap'
        }
    })
);

export const LensNumberDisplay: React.FunctionComponent<LensNumberDisplayProps> = observer(({jobNumber, side}) => {

    const classes = useStyles();

    const sideText = {
        left: t`Left`,
        right: t`Right`
    }[side];

    return <Box display={'flex'} flexDirection={'column'} alignItems={'center'} justifyContent={'center'} height={'100%'}>
        <Typography className={classes.headerText} variant={'h6'}>{sideText}</Typography>
        <Typography className={classes.headerText} variant={'subtitle1'}>
            <Box fontStyle={'italic'} color={grey[700]} mt={-1}>
                {`Lens #${jobNumber}`}
            </Box>
        </Typography>
    </Box>;
});
