import React from "react";
import {observer} from "mobx-react-lite";
import {Box} from "@material-ui/core";
import {OrderModel} from "../../../stores/OrderStore";
import {useModelContext} from "@rx-suite/ui";
import {OrderProcessesTableHeader} from "./order_process_table_components/OrderProcessesTableHeader";
import {OrderProcessesTableRow} from "./order_process_table_components/OrderProcessesTableRow";
import {RequiredProcessModel} from "../../../stores/RequiredProcessStore";
import {JobProcessStore} from "../../../stores/machine/JobProcessStore";
import {useRequiredProcessesContext} from "../../../hooks/useRequiredProcesses";

export type RequiredProcessGroup = {
    rank: number;
    display_name: string;
    name: string;
    left: RequiredProcessModel | null;
    right: RequiredProcessModel | null;
};

export const OrderProcessesTable: React.FunctionComponent = observer(({}) => {

    const model = useModelContext() as OrderModel;

    const { requiredProcesses } = useRequiredProcessesContext();

    const requiredProcessGroups = React.useMemo(() => {

        const processes: {[key: number]: RequiredProcessGroup} = {};

        requiredProcesses.forEach(requiredProcess => {

            const jobProcess = JobProcessStore.models.find((e) => e.id === requiredProcess.job_process_id);

            if (!jobProcess) {
                return;
            }

            if(!processes[requiredProcess.job_process_id]) {
                processes[requiredProcess.job_process_id] = {
                    rank: jobProcess.rank,
                    display_name: jobProcess.resolvedName,
                    name: jobProcess.name,
                    left: null,
                    right: null
                };
            }

            processes[requiredProcess.job_process_id][requiredProcess.side] = requiredProcess;
        });

        const requiredProcessArr = Object.values(processes);

        return requiredProcessArr.sort((a, b) => {
            if ((!a.left && !a.right) || (!b.left && !b.right)) {
                throw 'Required process with no job process';
            }
            const aVal = a.rank as number;
            const bVal = b.rank as number;
            return aVal - bVal;
        });

    }, [JobProcessStore.models, requiredProcesses]);

    return <Box display={'flex'} flexDirection={'column'}>
        <OrderProcessesTableHeader/>
        {requiredProcessGroups.map((requiredProcessGroup, i) => (
            <OrderProcessesTableRow
                order={model}
                rowData={requiredProcessGroup}
                isLastRow={i === (requiredProcessGroups.length - 1)}
            />))
        }
    </Box>;
});
