import React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {Alert} from "@material-ui/lab";
import classNames from "classnames";

type OrderRejectBannerProps = {
    rejectInfo: {
        reason: string | null;
        description: string | null;
    };
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        alignIcon: {
          '& .MuiAlert-icon': {
              alignItems: 'center'
          }
        },
        rejectText: {
            color: 'red'
        },
        title: {
            fontSize: '1.5rem'
        },
        subtitle: {
            fontSize: '1.2rem'
        }
    })
);

export const OrderRejectBanner: React.FunctionComponent<OrderRejectBannerProps> = observer(({rejectInfo}) => {

    const classes = useStyles();

    const rejectReason = rejectInfo.reason || t`N/A`;

    const rejectDescription = rejectInfo.description || t`No description available`;

    return <Alert severity="error" className={classes.alignIcon}>
        <span className={classNames(classes.rejectText, classes.title)}>{`Job Rejected (${rejectReason}) - `}</span> <span className={classNames(classes.rejectText, classes.subtitle)}>{rejectDescription}</span>
    </Alert>;
});
