import React, {useEffect, useMemo, useState} from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import { Alert } from "@material-ui/lab";
import {crossModuleLink} from "@rx-suite/stores";
import {useModelContext} from "@rx-suite/ui";
import {OrderModel} from "../../../stores/OrderStore";

type OrderStatusBannerProps = {

};

type OrderStatus = 'active' | 'expired' | 'error';

const useStyles = makeStyles((theme: Theme) =>
    createStyles({

    })
);

export const OrderStatusBanner: React.FunctionComponent<OrderStatusBannerProps> = observer(({}) => {

    const model = useModelContext() as OrderModel;

    const [status, setStatus] = useState<OrderStatus | null>(null);

    useEffect(() => {
        if (model.rx_data_order_id == null) {
            return;
        }

        const getStatus = async () => {
            try {
                const s = await model.getStatus();
                setStatus(s);
            } catch (e) {
                console.error('Could not fetch order status: ' + e);
                setStatus('error');
            }
        }
        getStatus();
    }, [model.rx_data_order_id]);

    const linkToRxDataJob = useMemo(() => {
        return crossModuleLink('rx_data', `/orders/all/${model.rx_data_order_id}/edit`);
    }, [model.rx_data_order_id]);

    if (!status || status === 'active') {
        return null;
    }

    if (status === 'error') {
        return (
            <Box mb={1}>
                <Alert severity={'warning'}>
                    {t`Something went wrong while checking the status of this order. Try refreshing or contact support if this issue persists.`}
                </Alert>
            </Box>
        );
    }

    return (
        <Box mb={1}>
            <Alert severity={'warning'}>
                {t`This order is no longer active and will no longer be synchronized. Click`} <a href={linkToRxDataJob}>{t`here`}</a> {t`to view the order status or contact support if you believe this is an error.`}
            </Alert>
        </Box>
    );
});
