import React from "react";
import {observer} from "mobx-react-lite";
import {Box} from "@material-ui/core";
import {t} from "@lingui/macro";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {ButtonField, useFlag} from "@rx-suite/ui";
import {faExchangeAlt} from "@rx-suite/pro-solid-svg-icons";
import {ChangeProcessesDialog} from "./ChangeProcessesDialog";
import {useIsSubmittingContext} from "../../../../../hooks/useIsSubmitting";
import {currentUserCanPermission} from "@rx-suite/stores";
import {OrderStore} from "../../../../../stores/OrderStore";

export const ChangeProcessesButton: React.FunctionComponent = observer(({}) => {

    const {
        isSubmitting,
        setIsSubmitting
    } = useIsSubmittingContext();

    const [open, setOpenTrue, setOpenFalse, toggleOpen] = useFlag(false);

    const canChangeProcesses = currentUserCanPermission({
        target: OrderStore.permissionTarget as string,
        action: 'ChangeProcesses'
    });

    if (!canChangeProcesses) {
        return null;
    }

    return (
        <Box ml={1}>
            <ButtonField
                text={t`Change Processes`}
                onClick={setOpenTrue}
                color={'primary'}
                variant={'contained'}
                startIcon={<FontAwesomeIcon icon={faExchangeAlt}/>}
                disabled={isSubmitting}
            />
            <ChangeProcessesDialog
                open={open}
                handleClose={setOpenFalse}
            />
        </Box>
    );
});
