import React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Dialog, DialogTitle, Theme, Box} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {BreadModel, makeOptionsColumn} from "@rx-suite/ui";
import {ORDER_HISTORY_EVENT_TYPE, OrderHistoryStore} from "../../../../../stores/OrderHistoryStore";
import {makeOrderHistoryDataColumn} from "./makeOrderHistoryDataColumn";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import moment from "moment";

type OrderHistoryDialogProps = {
    orderId: number;
    open: boolean;
    handleClose: () => void;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({

    })
);

export const OrderHistoryDialog: React.FunctionComponent<OrderHistoryDialogProps> = observer(({orderId, open, handleClose}) => {

    const classes = useStyles();

    const dialogContent = React.useMemo(() => {

        const columns = [
            makeOptionsColumn('event_type', t`Event Type`, ORDER_HISTORY_EVENT_TYPE.slice()),
            makeOrderHistoryDataColumn(),
            {
                Header: t`Time`,
                accessor: d => d.time,
                id: 'time',
                Cell: (cellInfo: {value: string }) => {
                    const systemSettings = SystemSettingStore.selectedModel as SystemSettingModel;
                    return systemSettings.printDateTime(moment(cellInfo.value));
                },
                filterable: false
            }
        ];

        return <BreadModel
            store={OrderHistoryStore}
            Form={() => {}} // No form
            columns={columns}
            tableProps={{
                showCreateButton: false,
                defaultSorted: [{id: 'time', desc: true}],
                defaultFiltered: [{id: 'order_id', value: orderId, strictMatchFilter: true}],
                suppressActionColumn: true,
                suppressWrapper: true,
                rememberFetchParams: false
            }}
        />;

    }, [orderId]);


    return (
        <Dialog open={open} onClose={handleClose} maxWidth={'md'} fullWidth>
            <DialogTitle>{t`Order History`}</DialogTitle>
            <Box p={2}>
                {dialogContent}
            </Box>
        </Dialog>
    );
});
