import React from "react";
import {Column} from "react-table";
import {t} from "@lingui/macro";
import {OrderHistoryEventType} from "../../../../../stores/OrderHistoryStore";
import {buildRejectDescription} from "../../../../../stores/OrderStore";

export const makeOrderHistoryDataColumn = (): Column => {

    return {
        id: '_data',
        Header: t`Information`,
        accessor: d => d,
        sortable: false,
        filterable: false,
        Cell: (cellInfo: { value: any }) => {

            if (!cellInfo || !cellInfo.value) {
                return t`N/A`;
            }

            const orderHistory = cellInfo.value;

            if (orderHistory.event_type == null || !orderHistory.data) {
                return t`N/A`;
            }

            const orderHistoryEventType = orderHistory.event_type as OrderHistoryEventType;
            const orderHistoryData = JSON.parse(orderHistory.data);

            const buildMethod = {
                'order_create': () => { return 'Order created.'; },
                'order_reject': () => { return buildRejectDescription(orderHistoryData.reject_reason, orderHistoryData.reject_data); },
                'order_unreject': () => { return 'Job was unrejected.'; },
                'order_update': () => { return orderHistoryData.location ? `Order updated while at location(${orderHistoryData.location}).` : `Order updated.`; },
                'process_update': () => { return `${orderHistoryData.updatedProcesses.map((process: {processId: number, source: string}) => { return `${process.processId} - ${process.source}`}).join(' ')}.`; },
                'location_update': () => { return `Location updated to ${orderHistoryData.location}.`; },
                'order_complete': () => { return 'Order complete.'; },
                'process_set': () => { return 'Initial processes set.'; },
                'order_rework': () => { return `Job reworked: ${orderHistoryData.side}`; }
            }[orderHistoryEventType];

            return buildMethod();
        }
    }

};