import React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {ButtonField, useFlag, useModelContext} from "@rx-suite/ui";
import {faEject} from "@rx-suite/pro-solid-svg-icons";
import {useIsSubmittingContext} from "../../../../../hooks/useIsSubmitting";
import {OrderModel} from "../../../../../stores/OrderStore";
import {useSnackbar} from "notistack";
import {blue, red} from "@material-ui/core/colors";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        unrejectBtn: {
            backgroundColor: blue[500],
            color: 'white',
            '&:hover': {
                backgroundColor: blue[700]
            }
        },
        rejectBtn: {
            backgroundColor: red[500],
            color: 'white',
            '&:hover': {
                backgroundColor: red[700]
            }
        }
    })
);

export const OrderRejectButton: React.FunctionComponent = observer(({}) => {

    const classes = useStyles();

    const {enqueueSnackbar} = useSnackbar();
    const order = useModelContext() as OrderModel;

    const [loading, setLoadingTrue, setLoadingFalse, toggleLoading] = useFlag(false);

    const {
        isSubmitting,
        setIsSubmitting
    } = useIsSubmittingContext();

    const handleReject = React.useCallback(async () => {

        if (isSubmitting) {
            return;
        }

        setLoadingTrue();
        setIsSubmitting(true);

        try {
            await order.toggleReject();
            enqueueSnackbar(`Success`, { variant: 'success' });
        } catch (e) {
            enqueueSnackbar(`Failed`, { variant: 'error' });
        }

        setIsSubmitting(false);
        setLoadingFalse();

    }, []);

    return (
        <Box>
            <ButtonField
                text={order.isRejected() ? t`UnReject` : t`Reject`}
                onClick={handleReject}
                color={'primary'}
                variant={'contained'}
                startIcon={<FontAwesomeIcon icon={faEject}/>}
                disabled={isSubmitting}
                loading={loading}
                className={order.isRejected() ? classes.unrejectBtn : classes.rejectBtn}
            />
        </Box>
    );
});
