import React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Grid, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import classNames from "classnames";
import {grey} from "@material-ui/core/colors";

type OrderProcessesTableCellProps = {
    cellComponent: JSX.Element;
    cellSize: CellSize;
    isLastCell: boolean;
};

export type CellSize = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12;

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        gridCell: {
            textAlign: 'center',

            borderStyle: 'solid',
            borderColor: grey[400],
            borderLeftWidth: '0',
            borderTopWidth: '0',
            borderBottomWidth: '0',
            borderRightWidth: '1px'
        },
        lastCellOfRow: {
            borderRightWidth: '0',
        }
    })
);

export const OrderProcessesTableCell: React.FunctionComponent<OrderProcessesTableCellProps> = observer(({cellComponent, cellSize, isLastCell}) => {

    const classes = useStyles();

    return <Grid item xs={cellSize}
                 className={classNames({
                     [classes.gridCell]: true,
                     [classes.lastCellOfRow]: isLastCell
                 })}
    >
        {cellComponent}
    </Grid>;
});
