import React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Grid, Theme, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import classNames from "classnames";
import {grey} from "@material-ui/core/colors";
import {CellSize} from "./OrderProcessesTableCell";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {OrderNumberDisplay} from "../OrderNumberDisplay";
import {useModelContext} from "@rx-suite/ui";
import {OrderModel} from "../../../../stores/OrderStore";
import { LensNumberDisplay } from "../LensNumberDisplay";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        gridRow: {
            borderStyle: 'solid',
            borderColor: grey[400],
            borderLeftWidth: '1px',
            borderTopWidth: '1px',
            borderBottomWidth: '0',
            borderRightWidth: '1px'
        },
        lastRowOfGrid: {
            borderBottomWidth: '1px'
        },
        gridCell: {
            textAlign: 'center',

            borderStyle: 'solid',
            borderColor: grey[400],
            borderLeftWidth: '0',
            borderTopWidth: '0',
            borderBottomWidth: '0',
            borderRightWidth: '1px'
        },
        header: {
            boxShadow: '0px 2px 2px -2px rgba(0,0,0,0.75)'
        },
        lastCellOfRow: {
            borderRightWidth: '0',
        },
        headerText: {
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            whiteSpace: 'nowrap'
        }
    })
);

export const OrderProcessesTableHeader: React.FunctionComponent = observer(({}) => {

    const classes = useStyles();
    const model = useModelContext() as OrderModel;

    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const displayRightLensFirst = systemSettingModel?.displayRightLensFirst();

    const columnNames = [t`Process Name`, t`Capabilities`, t`State`, t`Capabilities`, t`State`, t`Actions`];

    const cellSizes: ReadonlyArray<CellSize> = React.useMemo(() => {
        return [3, 2, 1, 2, 1, 3];
    }, []);

    const topComponent = React.useMemo(() => {

        const leftComponent = <LensNumberDisplay jobNumber={model.job_numbers.left} side={'left'} />;
        const rightComponent = <LensNumberDisplay jobNumber={model.job_numbers.right} side={'right'} />;

        return <Grid container item xs={12} className={classNames(classes.gridRow)}>
            <Grid item xs={cellSizes[0]} className={classNames(classes.gridCell)}>
                <OrderNumberDisplay orderNumber={model.number}/>
            </Grid>
            <Grid item xs={cellSizes[1] + cellSizes[2]} className={classNames(classes.gridCell)}>
                {displayRightLensFirst ? rightComponent : leftComponent}
            </Grid>
            <Grid item xs={cellSizes[3] + cellSizes[4]} className={classNames(classes.gridCell)}>
                {displayRightLensFirst ? leftComponent : rightComponent}
            </Grid>
            <Grid item xs={cellSizes[5]} className={classNames(classes.gridCell, classes.lastCellOfRow)}>
                {/* Empty */}
            </Grid>
        </Grid>

    }, [displayRightLensFirst, model.job_numbers, model.number]);

    return <Grid container spacing={0}>
        {topComponent}
        <Grid container item xs={12} className={classNames(classes.gridRow, classes.lastRowOfGrid)}>
            {columnNames.map((cName, i) => {
                return <Grid item xs={cellSizes[i]}
                     key={`order-process-table-header-${i}`}
                     className={classNames({
                        [classes.gridCell]: true,
                        [classes.header]: true,
                        [classes.lastCellOfRow]: i === (columnNames.length - 1)
                    })}
                >
                    <Typography className={classes.headerText} variant={'body1'}>{cName}</Typography>
                </Grid>;
            })}
        </Grid>
    </Grid>;
});
