import React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {RequiredProcessHistoryButton} from "./action_cell_components/RequiredProcessHistoryButton";
import {RequiredProcessCompleteButton} from "./action_cell_components/RequiredProcessCompleteButton";
import {OrderModel} from "../../../../../stores/OrderStore";
import {RequiredProcessResetButton} from "./action_cell_components/RequiredProcessResetButton";
import {RequiredProcessReworkButton} from "./action_cell_components/RequiredProcessReworkButton";
import {useFlag} from "@rx-suite/ui";
import {RequiredProcessReworkSelect} from "./action_cell_components/RequiredProcessReworkSelect";

type ActionsCellProps = {
    order: OrderModel;
    jobProcessRank: number;
    requiredProcessIds: {
        left?: number;
        right?: number;
    };
    disableRework: boolean;
};


export const ActionsCell: React.FunctionComponent<ActionsCellProps> = observer(({order, jobProcessRank, requiredProcessIds, disableRework}) => {


    const [reworking, setReworkingTrue, setReworkingFalse, toggleReworking] = useFlag(false);

    if (reworking) {
        return <Box display={'flex'} alignItems={'center'} justifyContent={'center'} height={'100%'} flexWrap={'wrap'}>
            <RequiredProcessReworkSelect
                order={order}
                jobProcessRank={jobProcessRank}
                onReworkFinish={setReworkingFalse}
            />
        </Box>;
    }

    return <Box display={'flex'} alignItems={'center'} justifyContent={'center'} height={'100%'} flexWrap={'wrap'}>
        <RequiredProcessCompleteButton
            order={order}
            jobProcessRank={jobProcessRank}
        />
        <RequiredProcessResetButton
            order={order}
            jobProcessRank={jobProcessRank}
        />
        <RequiredProcessReworkButton
            disableRework={disableRework}
            onClickRework={setReworkingTrue}
        />
        <RequiredProcessHistoryButton
            requiredProcessIds={requiredProcessIds}
        />
    </Box>;
});
