import React from "react";
import {observer} from "mobx-react-lite";
import {Box, Chip, createStyles, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {CapabilityStore} from "../../../../../stores/machine/CapabilityStore";

type CapabilitiesCellProps = {
    capability_ids: Array<number>;
    colors: {
        text: string;
        background: string;
    };
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({

    })
);

export const CapabilitiesCell: React.FunctionComponent<CapabilitiesCellProps> = observer(({capability_ids, colors}) => {

    const classes = useStyles();

    const capabilities = React.useMemo(() => {
        const found = CapabilityStore.models.filter((capability) => capability_ids.includes(capability.id));
        if (!found) {
            return [];
        }
        return found.map((capability) => capability.resolvedName);
    }, [capability_ids]);

    return <Box display={'flex'} alignItems={'center'} justifyContent={'space-around'} height={'100%'} bgcolor={colors.background} flexWrap={'wrap'}>
        {capabilities.map((c) => (
            <Chip
                label={c}
                variant={'outlined'}
                size={'medium'}
                style={{color: colors.text, borderColor: colors.text, fontWeight: 'bold', fontSize: '1rem'}}
            />
        ))}
    </Box>;
});
