import React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Divider, IconButton, Popover, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {AccessTime} from "@material-ui/icons";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import moment from "moment";

type ProcessNameCellProps = {
    processName: string;
    completeAt: string | null;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        processText: {
            fontSize: '1.15rem'
        }
    })
);

export const ProcessNameCell: React.FunctionComponent<ProcessNameCellProps> = observer(({processName, completeAt}) => {

    const classes = useStyles();

    const [anchorEl, setAnchorEl] = React.useState<HTMLButtonElement | null>(null);
    const systemSettings = SystemSettingStore.selectedModel as SystemSettingModel;

    const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
        setAnchorEl(event.currentTarget);
    };

    const handleClose = () => {
        setAnchorEl(null);
    };

    const open = Boolean(anchorEl);
    const id = open ? 'schedule-popover' : undefined;

    return <Box display={'flex'} alignItems={'center'} height={'100%'}>
        <Box ml={2} flex={7} display={'flex'} justifyContent={'flex-start'}>
            <Typography  className={classes.processText}>{processName}</Typography>
        </Box>
        <Box flex={1} display={'flex'} alignItems={'center'} justifyContent={'center'} height={'100%'}>
            <Divider orientation="vertical" flexItem/>
            <Box flex={1}>
                {completeAt && <>
                    <IconButton
                        size={'small'}
                        onClick={handleClick}
                    >
                        <AccessTime/>
                    </IconButton>
                    <Popover
                        id={id}
                        open={open}
                        anchorEl={anchorEl}
                        onClose={handleClose}
                        anchorOrigin={{
                            vertical: 'top',
                            horizontal: 'left',
                        }}
                        transformOrigin={{
                            vertical: 'bottom',
                            horizontal: 'left',
                        }}
                    >
                        <Box p={1}>
                            {`Process will be completed at ${systemSettings.printTime(moment(completeAt))}`}
                        </Box>
                    </Popover>
                </>}
            </Box>
        </Box>
    </Box>;
});
