import React from "react";
import {observer} from "mobx-react-lite";
import {Box, Button, createStyles, IconButton, Theme} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faHistory} from "@rx-suite/pro-solid-svg-icons";
import {RequiredProcessHistoryDialog} from "./RequiredProcessHistoryDialog";
import {useFlag} from "@rx-suite/ui";

type RequiredProcessHistoryButtonProps = {
    requiredProcessIds: {
        left?: number;
        right?: number;
    };
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        icon: {
            fontSize: '1.25rem',
            padding: theme.spacing(0.25)
        }
    })
);

export const RequiredProcessHistoryButton: React.FunctionComponent<RequiredProcessHistoryButtonProps> = observer(({requiredProcessIds}) => {

    const classes = useStyles();

    const [open, setOpenTrue, setOpenFalse, toggleOpen] = useFlag(false);

    return <>
        <Box m={1}>
            <Button
                color={"primary"}
                onClick={setOpenTrue}
                size={'medium'}
                variant={'outlined'}
            >
                <FontAwesomeIcon icon={faHistory} className={classes.icon}/>
            </Button>
        </Box>
        <RequiredProcessHistoryDialog
            requiredProcessIds={requiredProcessIds}
            open={open}
            handleClose={setOpenFalse}
        />
    </>
});
