import React from "react";
import {Box, createStyles, Popover, Theme, Typography} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {grey} from "@material-ui/core/colors";

type RequiredProcessHistoryStateCellProps = {
    state: string;
    comment: string;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        details: {
            color: grey[600],
            textDecoration: 'underline',
            '&:hover': {
                cursor: 'pointer',
                color: grey[400]
            }
        }
    })
);

export const RequiredProcessHistoryStateCell: React.FunctionComponent<RequiredProcessHistoryStateCellProps> = observer(({state, comment}) => {

    const classes = useStyles();

    const [anchorEl, setAnchorEl] = React.useState<HTMLButtonElement | null>(null);

    const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
        setAnchorEl(event.currentTarget);
    };

    const handleClose = () => {
        setAnchorEl(null);
    };

    const open = Boolean(anchorEl);
    const id = open ? 'aborted-popover' : undefined;

    return <Box width={'100%'} display={'flex'} flexDirection={'row'} justifyContent={'space-between'} alignItems={'center'}>
        <Typography>{state}</Typography>
        {state == 'ABORTED' && <>
            <Typography
                onClick={handleClick}
                component="span"
                color="primary"
                variant="subtitle2"
                className={classes.details}
            >
                {t`View Details`}
            </Typography>
            <Popover
                id={id}
                open={open}
                anchorEl={anchorEl}
                onClose={handleClose}
                anchorOrigin={{
                    vertical: 'top',
                    horizontal: 'left',
                }}
                transformOrigin={{
                    vertical: 'bottom',
                    horizontal: 'left',
                }}
            >
                <Box p={1}>
                    {comment}
                </Box>
            </Popover>
        </>}
    </Box>;
});
