import React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {ButtonField} from "@rx-suite/ui";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faRecycle} from "@rx-suite/pro-solid-svg-icons";
import {OrderModel} from "../../../../../../stores/OrderStore";
import {useSnackbar} from "notistack";
import {useIsSubmittingContext} from "../../../../../../hooks/useIsSubmitting";
import {orange} from "@material-ui/core/colors";

type RequiredProcessResetButtonProps = {
    order: OrderModel;
    jobProcessRank: number;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        resetBtn: {
            backgroundColor: orange[600],
            color: 'white',
            '&:hover': {
                backgroundColor: orange[800]
            }
        }
    })
);

export const RequiredProcessResetButton: React.FunctionComponent<RequiredProcessResetButtonProps> = observer(({order, jobProcessRank}) => {

    const classes = useStyles();

    const {enqueueSnackbar} = useSnackbar();

    const [loading, setLoading] = React.useState<boolean>(false);

    const {
        isSubmitting,
        setIsSubmitting
    } = useIsSubmittingContext();

    const handleReset = React.useCallback(async () => {

        setLoading(true);
        setIsSubmitting(true);

        const resp = await order.resetDownTo(jobProcessRank);

        setIsSubmitting(false);
        setLoading(false);

        enqueueSnackbar(t`Updated Successfully`, {variant: 'success'});

    }, [order, jobProcessRank]);

    return <ButtonField
        text={t`Reset`}
        onClick={handleReset}
        color={'secondary'}
        variant={'contained'}
        startIcon={<FontAwesomeIcon icon={faRecycle}/>}
        size={'medium'}
        disabled={isSubmitting}
        loading={loading}
        className={classes.resetBtn}
    />;
});
