import React from "react";
import {observer} from "mobx-react-lite";
import {Box, Button, createStyles, Theme} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faTrafficCone} from "@rx-suite/pro-solid-svg-icons";
import {useSnackbar} from "notistack";
import {makeStyles} from "@material-ui/core/styles";
import {purple} from "@material-ui/core/colors";
import {SettingStore} from "../../../../../../stores/SettingStore";
import {useIsSubmittingContext} from "../../../../../../hooks/useIsSubmitting";
import {currentUserCanPermission} from "@rx-suite/stores";
import {OrderStore} from "../../../../../../stores/OrderStore";

type RequiredProcessReworkButtonProps = {
    disableRework: boolean;
    onClickRework: () => void;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        reworkBtn: {
            backgroundColor: purple[800],
            color: 'white',
            '&:hover': {
                backgroundColor: purple[900]
            }
        },
        icon: {
            fontSize: '1.25rem',
            padding: theme.spacing(0.25)
        }
    })
);

export const RequiredProcessReworkButton: React.FunctionComponent<RequiredProcessReworkButtonProps> = observer(({disableRework, onClickRework}) => {

    const classes = useStyles();

    const canReworkProcess = currentUserCanPermission({
        target: OrderStore.permissionTarget as string,
        action: 'ReworkProcess'
    });

    const {
        isSubmitting,
        setIsSubmitting
    } = useIsSubmittingContext();

    if (!canReworkProcess) {
        return null;
    }

    return (
        <Box ml={1}>
            <Button
                className={classes.reworkBtn}
                color={"primary"}
                onClick={onClickRework}
                size={'medium'}
                variant={'contained'}
                disabled={isSubmitting || disableRework}
            >
                <FontAwesomeIcon icon={faTrafficCone} className={classes.icon}/>
            </Button>
        </Box>
    );
});
