import * as React from "react";
import {observer} from "mobx-react-lite";
import {useMemo} from "react";
import {t} from "@lingui/macro";
import {ModelForm, ModelFormProps} from "@rx-suite/ui";
import {useRouterOnline} from "../../hooks/useRouterOnline";
import { Model } from "@rx-suite/data";
import {RouterOnlineAlert} from "./RouterOnlineAlert";

type RouterResourceModelForm = {
    model: Model;
} & Partial<Omit<ModelFormProps, 'submitText' | 'model'>>

export const RouterResourceModelForm: React.FunctionComponent<RouterResourceModelForm> = observer(({model, ...props}) => {
    const routerOnline = useRouterOnline();

    const text = useMemo(() => {
        if(model.isNew){
            return t`Create`;
        }

        if(!routerOnline){
            return t`Update`
        }

        return  t`Update & Synchronize`;
    }, [model.isNew, routerOnline])

    return (
        <React.Fragment>
            {!model.isNew && <RouterOnlineAlert/>}
            <ModelForm model={model} submitText={text} {...props} />
        </React.Fragment>
    )
})