import React from "react";
import {observer} from "mobx-react-lite";
import {Button} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {RSDToolTip} from "./RSDToolTip";
import {HintButton} from "@rx-suite/ui";
import {makeStyles} from "@material-ui/core/styles";
import {Model} from "@rx-suite/data";
import {useRouterOnline} from "../../hooks/useRouterOnline";

interface RSDButtonProps {
    label: string;
    model: Model;
    handleOnClick: () => void;
    forceDisable?: boolean
    variant?: "contained" | "outlined";
}

const useStyles = makeStyles(theme => ({
    flex: {
        display: 'flex',
        alignItems: 'center'
    },
    button: {
        height: '42px'
    }
}));

export const RSDButton: React.FunctionComponent<RSDButtonProps> = observer(({label, model, handleOnClick, forceDisable, variant}) => {
    const classes = useStyles();

    // The field is disabled by order of priority:
    // - If the model is new, don't disable the field
    // - Otherwise, if the router is online, disable the field
    let disable = false
    if(useRouterOnline()){ disable = true }
    if(model.isNew) { disable = false }
    if(forceDisable) { disable = true}

    const hint = RSDToolTip(disable)

    return (
        <span className={classes.flex}>
            <Button className={classes.button} variant={variant ? variant : "contained"} color="secondary" onClick={handleOnClick} disabled={disable}>
                {label}
            </Button>
            {hint && <HintButton {...hint}/>}
        </span>
    )
});
