import React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, useModelContext} from "@rx-suite/ui";
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {TagFormBody} from "./TagFormBody";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";

type TagDialogProps = {
    open: boolean;
    handleClose: () => void;
}

export const TagDialogComponent: React.FunctionComponent<TagDialogProps> = observer(({open, handleClose}) => {
    const {enqueueSnackbar} = useSnackbar();
    const [isSubmitting, setIsSubmitting] = React.useState<boolean>(false);

    const model = useModelContext();

    const handleSubmit = async () => {
        setIsSubmitting(true);

        try {
            model.viewModel.submit();
            await model.commit();
            enqueueSnackbar(`${t`Tag successfully created`}`, {variant: "success"});
            handleClose();
        }catch (err) {
            console.error(err)
            enqueueSnackbar(`${t`Failed to save new tag`}`, {variant: "error"});
        }

        setIsSubmitting(false);
    }

    return (
        <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title">
            <DialogTitle id="form-dialog-title">Add New Tag</DialogTitle>
            <DialogContent>
                <TagFormBody/>
                <DialogActions>
                    <ButtonField
                        text={t`Close`}
                        onClick={handleClose}
                        color={'secondary'}
                        variant={'text'}
                    />
                    <ButtonField
                        text={t`Submit`}
                        onClick={handleSubmit}
                        loading={isSubmitting}
                        disabled={!model.isValid}
                        color={'secondary'}
                        variant={'text'}
                    />
                </DialogActions>
            </DialogContent>
        </Dialog>
    )
});
