import React from "react";
import {observer} from "mobx-react-lite";
import {ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";
import {Box, createStyles, Theme, Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {grey} from "@material-ui/core/colors";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        bold: {
            fontWeight: 'bold'
        },
        caption: {
            color: grey[500],
            fontSize: '0.75rem'
        }
    })
);

export const TagFormBody: React.FunctionComponent = observer(() => {
    const model = useModelContext();
    const classes = useStyles();

    const defaultTagHint = React.useMemo(() => {
        return (
            <div>
                <Box mb={0.5}>
                    <Trans>The default value used if a job's data does not contain this tag.</Trans>
                </Box>
                <Box>
                    <Trans><span className={classes.bold}>Important:</span> A default value should be provided if a tag may not have a value, otherwise, any conditions using this tag may return unexpected results.</Trans>
                </Box>
            </div>
        )
    }, []);

    const valueTypeOptions = React.useMemo(() => {
        return [
            {label: 'String', value: 'string'},
            {label: 'Number', value: 'number'}
        ]
    }, []);

    return (
       <React.Fragment>
           <ModelInput name={'tag'} disabled={!model.isNew}/>
           <ModelSelect name={'value_type'} options={valueTypeOptions} disabled={!model.isNew}/>
           <ModelInput name={'default_value'} hint={
               {
                   title: 'Tag Default Value',
                   children: defaultTagHint
               }
           }
           />
           <Typography variant={'h6'} className={classes.caption}>
               <Trans>Important: Use a dot to represent decimal values in numbers (ex: 0.5 instead of 0,5).</Trans>
           </Typography>
       </React.Fragment>
    )
});
