import { t } from "@lingui/macro"
import {ConnectorModel, ControlActionConfig} from "../../../stores/ConnectorStore";
import React from "react";
import {Box, Grid} from "@material-ui/core";
import {BreadModelListBadge} from "@rx-suite/ui";
import {SubdirectoryArrowRight} from "@material-ui/icons";
import {grey} from "@material-ui/core/colors";
import {Column} from "react-table";

export const useConnectorControlActionColumn = (): Column => {
    const controlActionListFromConfig = (config: ControlActionConfig): { key: string, isSubAction: boolean }[] => {
        const controlActions = [];

        if(config.fetch){
            if(config.fetch.enabled){
                controlActions.push({ key: t`Allow Job Start`, isSubAction: false });
            }
            if(config.fetch.restart){
                controlActions.push({ key: t`Restart Jobs`, isSubAction: true });
            }
        }

        if(config.setProcesses){
            if(config.setProcesses.process !== null){
                controlActions.push({ key:t`Set Process (${config.setProcesses.process} - ${config.setProcesses.setToState})`, isSubAction: false });

                if(config.setProcesses.finishPrevious) {
                    controlActions.push({ key: t`Finish Previous Processes`, isSubAction: true });
                }
                if(config.setProcesses.restartNext) {
                    controlActions.push({ key: t`Restart Next Processes`, isSubAction: true });
                }
            }
        }

        if(config.validateProcesses){
            if(config.validateProcesses.process !== null){
                controlActions.push({ key:t`Validate Process (${config.validateProcesses.process})`, isSubAction: false });

                if(config.validateProcesses.ensureNoPriorAbort) {
                    controlActions.push({ key: t`Ensure No Prior Aborts`, isSubAction: true });
                }
                if(config.validateProcesses.ensurePriorCompleted) {
                    controlActions.push({ key: t`Ensure Prior Completed`, isSubAction: true });
                }
            }
        }

        if(config.addControlProcess){
            if(config.addControlProcess.process !== null){
                controlActions.push({ key:t`Control Process (${config.addControlProcess.process})`, isSubAction: false });
            }
        }

        if(config.unreject){
            controlActions.push({ key: t`Unreject Jobs`, isSubAction: false });
        }

        if(config.holdStarted){
            controlActions.push({ key: t`Hold Started Jobs`, isSubAction: false });
        }

        if(config.holdReject){
            controlActions.push({ key: t`Hold Rejected Jobs`, isSubAction: false });
        }

        if(config.splitJobsToOutput){
            controlActions.push({ key: t`Balance Jobs to Outputs`, isSubAction: false });
        }

        if(config.forceFullPathResolve){
            controlActions.push({ key: t`Force Full Path Resolve`, isSubAction: false });
        }

        return controlActions;
    }

    return (
        {
            Header: t`Control Actions`,
            id: 'control_Action',
            accessor: (connector: ConnectorModel) => connector,
            filterable: false,
            Cell: (cellInfo: {value: ConnectorModel }) => {
                if(!cellInfo.value.isInput){
                    return null;
                }

                const config = cellInfo.value.viewModel.control_action_config as ControlActionConfig;

                if(!config || typeof config === 'string'){
                    return null;
                }

                return (
                    <Grid container direction={'column'}>
                        {
                            controlActionListFromConfig(config).map(entry => (
                                <Grid container>
                                    {entry.isSubAction && <SubdirectoryArrowRight style={{color: grey[600]}}/>}
                                    <Box>
                                        <BreadModelListBadge text={entry.key}/>
                                    </Box>
                                </Grid>
                            ))
                        }
                    </Grid>
                )
            }
        }
    )
}


