import { t } from "@lingui/macro"
import * as React from "react";
import {MachineModel} from "../../../stores/machine/MachineStore";
import {Observer} from "mobx-react-lite";
import {States} from "../../../stores/machine/MesMachineStateStore";
import {BreadModelListBadge} from "@rx-suite/ui";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {green, grey, red} from "@material-ui/core/colors";
import {faCog} from "@rx-suite/pro-solid-svg-icons/faCog";
import {faWrench} from "@rx-suite/pro-solid-svg-icons/faWrench";
import {MachineStateColorStore} from "@rx-suite/stores";

export const useMachineStateColumn = () => {
    const resolveColor = (state: States) => {
        let model = MachineStateColorStore.models.find(status => status.status_name == state);

        if(model){
            return model.color as string;
        }else{
            return grey[600];
        }
    }

    const resolveCellValue = (machine: MachineModel) => {
        if (machine.forced_state === 'online') {
            return {
                text: t`ONLINE (FORCED)`,
                color: green[500],
                icon: faCog
            };
        }

        if (machine.forced_state === 'offline') {
            return {
                text: t`OFFLINE (FORCED)`,
                color: red[500],
                icon: faWrench
            };
        }

        const resolvedValue = machine.external_attributes.state;
        if (!resolvedValue) {
            return {
                text: t`UNKNOWN`,
                color: grey[500],
                icon: faWrench
            };
        }

        const upperCaseVal = resolvedValue.toUpperCase() as States;

        return {
            text: upperCaseVal,
            color: resolveColor(upperCaseVal),
            icon: machine.online_states.includes(upperCaseVal) ? faCog : faWrench
        }
    }

    return (
        {
            Header: t`State`,
            id: 'state',
            accessor: (model: MachineModel) => model,
            filterable: false,
            sortable: false,
            Cell: (cellInfo: { value: MachineModel }) => {
                const {text, icon, color} = resolveCellValue(cellInfo.value);

                // Need to use observer within tableCells, else to value won't update
                return <Observer>
                    {
                        () => {
                           return <BreadModelListBadge
                               text={text}
                               startIcon={
                                   <FontAwesomeIcon
                                       height={'100%'}
                                       style={{fontSize: '1.25rem', marginTop: '2px', marginBottom: '2px'}}
                                       color={color}
                                       icon={icon}
                                   />
                               }
                           />
                        }
                    }
                </Observer>
            }
        }
    )
}