import {consumer, dataConfig, Transport} from "@rx-suite/data";
import {useEffect, useState} from "react";
import moment from "moment";

export type System = {
    name: string,
    online: boolean,
    lms_config_id?: number
}

type ExternalSystems = {
    systems: System[],
    updated_at: string
}

export const useExternalSystems = ():  [ExternalSystems, boolean]  => {
    const [externalSystemsStatus, setExternalSystemsStatus] = useState<ExternalSystems>({systems: [], updated_at: moment()});
    const [statusLoading, setStatusLoading] = useState<boolean>(false);

    const fetch = async () => {
        setStatusLoading(true);

        const token = dataConfig.accessToken;
        const requestInit: RequestInit = {
            method: 'get',
            headers: {
                Authorization: `TOKEN ${token}`,
                X_CSRF_TOKEN: (document.querySelector('head > meta[name="csrf-token"]') as any)?.content
            }
        }
        const resp = await Transport.fetch('/router/systems_status', requestInit);
        if(resp.ok) {
            setExternalSystemsStatus(await resp.json());
        } else {
            console.error('Could not get External Systems Status');
        }

        setStatusLoading(false);
    }

    const setSubscription = () => {
        return consumer.subscriptions.create({
            channel: 'ExternalSystemsChannel'
        }, {
            received(data: ExternalSystems) {
                setExternalSystemsStatus(data);
            }
        })
    }

    useEffect(() => {
        // Fetch starting values
        fetch();

        // Set subscription for updates
        const subscription = setSubscription();
        return () => {
            consumer.subscriptions.remove(subscription);
        }
    }, []);

    return [externalSystemsStatus, statusLoading];
}