import * as React from "react";
import {debounce} from "debounce";
import {when} from "mobx";
import {FetchParams} from "@rx-suite/data";

export const useFilteringDebounce = (predicate: boolean, setFetchParams: (state: FetchParams) => void) => {
    const filtering = React.useRef(false);
    const mostRecentQueuedFetchTime = React.useRef<number | null>(null);

    const fetchData = React.useCallback((state: FetchParams, _) => {
        filtering.current = false;
        const thisFetchTime = Date.now()
        mostRecentQueuedFetchTime.current = thisFetchTime;
        when(() => predicate, () => {
            if (!mostRecentQueuedFetchTime.current || (thisFetchTime >= mostRecentQueuedFetchTime.current)) {
                setFetchParams(state);
            }
        });
    }, [predicate, setFetchParams]);

    const debouncedFetchData = React.useMemo(() => {
        return debounce(fetchData, 1000)
    }, [fetchData]);

    const fetchDataStrategy = React.useCallback((state, instance) => {
        if (filtering.current) {
            return debouncedFetchData(state, instance);
        } else {
            return fetchData(state, instance);
        }
    }, [debouncedFetchData, fetchData]);

    const handleFilteredChange = React.useCallback(() => {
        filtering.current = true;
    }, []);

    return [handleFilteredChange, fetchDataStrategy]
}