import React, {useEffect} from "react";
import {RequiredProcessModel, RequiredProcessStore} from "../stores/RequiredProcessStore";
import {useFlag} from "@rx-suite/ui";
import {DataStore} from "@rx-suite/data";

export const useRequiredProcessClonedStore = (required_process_ids: number[]):  [DataStore<RequiredProcessModel>, boolean, (required_process_ids: number[]) => void]  => {
    const [fetching, setFetchingTrue, setFetchingFalse, toggleFetching] = useFlag(false);

    const clonedStore = React.useMemo(() => {
        console.log('Cloning store');
        return RequiredProcessStore.clone();
    }, []);

    const refreshClonedStore = React.useCallback((required_process_ids: number[]) => {

        setFetchingTrue();
        clonedStore.data.clear();

        if (required_process_ids.length <= 0) {
            console.log('No processes to show');
            setFetchingFalse();
            return;
        }

        const getRequiredProcesses = async () => {
            // previous subscription is unsubscribed inside getByIdsAndSubscribe
            await clonedStore.getByIdsAndSubscribe(required_process_ids.map(e => e.toString()));
            setFetchingFalse();
        };

        console.log('re-subscribe');
        getRequiredProcesses();

    }, [clonedStore, setFetchingTrue, setFetchingFalse]);

    useEffect(() => {

        refreshClonedStore(required_process_ids);

        return () => {
            console.log('final unsubscribe');
            clonedStore.unsubscribe(); // unsubscribe the last subscription
        }

    }, []);

    return [clonedStore, fetching, refreshClonedStore];
}