import React from "react";
import {ModelProvider, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {LinearProgress, Grid, Box, Theme, createStyles} from "@material-ui/core";
import {t} from "@lingui/macro";
import {PlayArrow, Stop} from "@material-ui/icons";
import {ModelActionButton} from "../../components/generic/ModelActionButton";
import { RouterStatusIndicator } from "../../components/command_center/RouterStatusIndicator";
import {currentUserCan} from "@rx-suite/stores";
import {makeStyles} from "@material-ui/core/styles";
import {ExternalSystemsStatus} from "../../components/command_center/ExternalSystemsStatus";
import {EventsTable} from "../../components/command_center/EventsTable";
import {RouterServerStore} from "../../stores/RouterServerStore";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        statusBox: {
            minWidth: '225px'
        },
        eventsTable: {
            marginLeft: theme.spacing(1.5),
            flexGrow: 1
        }
    })
);

export const CommandCenter: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const router = RouterServerStore.selectedModel;

    if(!router){
        return <LinearProgress/>
    }

    return (
        <React.Fragment>
            <PaddedPaper>
                <ModelProvider value={router}>
                    <Grid container alignItems={'flex-end'}>
                        <Box className={classes.statusBox}>
                            <RouterStatusIndicator/>
                        </Box>
                        <Box>
                            {
                                currentUserCan('router', 'start') &&
                                <ModelActionButton
                                    name={'start'}
                                    text={t`Start Router`}
                                    startIcon={<PlayArrow/>}
                                    disabled={router.running}
                                    color={'secondary'}
                                    size={'large'}
                                />

                            }
                            {
                                currentUserCan('router', 'stop') &&
                                <ModelActionButton
                                    name={'stop'}
                                    text={t`Stop Router`}
                                    startIcon={<Stop/>}
                                    disabled={!router.running}
                                    color={'secondary'}
                                    size={'large'}
                                />
                            }
                        </Box>
                    </Grid>
                </ModelProvider>
            </PaddedPaper>
            <Box mt={1.5}>
                <Grid container>
                    <Grid item md={4}>
                        <PaddedPaper style={{height: '100%'}}>
                            <ExternalSystemsStatus/>
                        </PaddedPaper>
                    </Grid>
                    <Grid item className={classes.eventsTable}>
                        <PaddedPaper>
                            <EventsTable/>
                        </PaddedPaper>
                    </Grid>
                </Grid>
            </Box>

        </React.Fragment>
    )
});