import React from "react";
import {FormProps, ModelInput, ModelForm, PaddedPaper, ModelProvider} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {TabsContainer} from "../../../../components/generic/TabsContainer";
import {t} from "@lingui/macro";
import {MopConnectorTab} from "./tabs/connectors/MopConnectorTab";
import {DeviceDataTrackingTab} from "../../../../components/devices/form/DeviceDataTrackingTab";
import {DeviceModel} from "../../../../stores/Device/DeviceStore";
import {useDeviceConnectors} from "../../../../hooks/device_form/useDeviceConnectors";
import {Box} from "@material-ui/core";
import {useRouterOnline} from "../../../../hooks/useRouterOnline";
import { RouterResourceModelForm } from "../../../../components/router/RouterResourceModelForm";

type MopDeviceFormProps = {
    model: DeviceModel
} & Omit<FormProps, 'model'>

export const MopDeviceForm: React.FunctionComponent<MopDeviceFormProps> = observer(({model}) => {
    React.useEffect(() => {
        useDeviceConnectors(model);
    }, [model]);

    if(model.isNew){
        return (
            <ModelForm model={model} suppressImportExport suppressMakeCopy>
                <ModelInput name={'name'}/>
                <ModelInput name={'number_of_outputs'}/>
            </ModelForm>
        )
    }

    return (
        <React.Fragment>
            <PaddedPaper>
                <RouterResourceModelForm model={model} suppressImportExport suppressMakeCopy suppressWrapper>
                    <ModelInput name={'name'} disabled={useRouterOnline()}/>
                </RouterResourceModelForm>
            </PaddedPaper>
            {
                !model.isNew &&
                <Box mt={1}>
                    <ModelProvider value={model}>
                        <PaddedPaper>
                            <TabsContainer tabs={
                                [
                                    {
                                        label: t`Connectors`,
                                        component: <MopConnectorTab/>,
                                        defaultTab: true
                                    },
                                    {
                                        label: t`Data Tracking`,
                                        component: <DeviceDataTrackingTab/>
                                    }
                                ]
                            }
                            />
                        </PaddedPaper>
                    </ModelProvider>
                </Box>
            }
        </React.Fragment>
    )
})