import React from "react";
import {FormProps, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ConnectorModel} from "../../../../../../stores/ConnectorStore";
import {t} from "@lingui/macro";
import {ModelFormDialog} from "../../../../../../components/generic/ModelFormDialog";
import {ConnectorStateSelect} from "../../../../../../components/connectors/form/ConnectorStateSelect";
import { ConnectorControlActionForm } from "../../../../../../components/connectors/form/control_actions/ConnectorControlActionForm";
import {useRouterOnline} from "../../../../../../hooks/useRouterOnline";
import {PathLengthInput} from "../../../../../../components/connectors/form/PathLengthInput";

type MopConnectorDialogFormProps = {
    model: ConnectorModel;
    setModel: React.Dispatch<React.SetStateAction<ConnectorModel | null>>
} & Omit<FormProps, 'model'>

export const MopConnectorDialogForm: React.FunctionComponent<MopConnectorDialogFormProps> = observer(({model, setModel}) => {
   return (
       <ModelFormDialog
           title={t`Edit Connector`}
           model={model}
           setModel={setModel}
       >
           <ModelInput name={'name'} disabled={useRouterOnline()}/>
           <ModelInput name={'connector_type'} disabled/>
           <ConnectorStateSelect/>
           {
               !model.isInput &&
               <>
                   <ModelInput
                       name={'path'}
                       disabled={useRouterOnline()}
                   />
                   <PathLengthInput/>
               </>
           }
           {
               model.isInput &&
               <ConnectorControlActionForm/>
           }
       </ModelFormDialog>
   )
});