import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {ConnectorModel, ConnectorStore} from "../../../../../../stores/ConnectorStore";
import ReactTable from "react-table";
import {MopConnectorDialogForm} from "./MopConnectorDialogForm";
import {useDialogEditColumn} from "../../../../../../hooks/table_columns/connector_form/useDialogEditColumn";
import {currentUserCan} from "@rx-suite/stores";
import {useConnectorControlActionColumn} from "../../../../../../hooks/table_columns/connector_form/useConnectorControlActionColumn";
import {useConnectorStateColumn} from "../../../../../../hooks/table_columns/connector_form/useConnectorStateColumn";

export const MopConnectorTab: React.FunctionComponent= observer(() => {
    const [dialogModel, setDialogModel] = React.useState<ConnectorModel|null>(null);

    const columns = React.useMemo(() => {
        const cols = [
            {Header: t`Name`, accessor: 'name'},
            {Header: t`Type`, accessor: 'connector_type'},
            useConnectorStateColumn(),
            useConnectorControlActionColumn()
        ]

        if(currentUserCan('connector', 'update')){
            cols.push(useDialogEditColumn(setDialogModel));
        }

        return cols;
    }, [])

    return (
        <React.Fragment>
            <ReactTable
                data={ConnectorStore.models}
                columns={columns}
                minRows={ConnectorStore.models.length}
                showPagination={false}
                defaultSorted={[{ id: 'name', desc: false}]}
                className={'-striped'}
                loading={ConnectorStore.isLoading}
            />
            {
                dialogModel &&
                <MopConnectorDialogForm
                    model={dialogModel}
                    setModel={setDialogModel}
                />
            }
        </React.Fragment>
    )
})