import React from "react";
import {FormProps, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ConnectorModel} from "../../../../../../stores/ConnectorStore";
import {t} from "@lingui/macro";
import {ModelFormDialog} from "../../../../../../components/generic/ModelFormDialog";
import {Alert} from "@material-ui/lab";
import {Box} from "@material-ui/core";
import { ConnectorControlActionForm } from "../../../../../../components/connectors/form/control_actions/ConnectorControlActionForm";
import {ConnectorStateSelect} from "../../../../../../components/connectors/form/ConnectorStateSelect";
import {PathLengthInput} from "../../../../../../components/connectors/form/PathLengthInput";

type OpcuaConnectorDialogFormProps = {
    model: ConnectorModel;
    setModel: React.Dispatch<React.SetStateAction<ConnectorModel | null>>
} & Omit<FormProps, 'model'>

export const OpcuaConnectorDialogForm: React.FunctionComponent<OpcuaConnectorDialogFormProps> = observer(({model, setModel}) => {
    return(
        <ModelFormDialog
            title={t`Edit Connector`}
            model={model}
            setModel={setModel}
        >
            <Alert severity={'info'}>
                {t`Some inputs of this form have been automatically populated according to the device type and cannot be edited.`}
            </Alert>
            <ModelInput name={'name'} label={t`Connector Name`} disabled/>
            <ModelInput name={'variable'} label={t`OPC UA Variable`} disabled/>
            <ModelInput name={'connector_type'} label={t`Type`} disabled/>
            {
                model.connector_type !== 'other' &&
                <ConnectorStateSelect/>
            }
            {
                !model.isInput && <PathLengthInput/>
            }
            {
                model.isInput &&
                <Box>
                    <ModelInput name={'priority'} type={'number'} inputProps={{max: '1', min: '0', step: '0.1'}}/>
                    <ModelInput name={'action_delay'}/>
                    <ConnectorControlActionForm/>
                </Box>
            }
        </ModelFormDialog>
    )
});