import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable, {Column} from "react-table";
import {ConnectorModel, ConnectorStore} from "../../../../../../stores/ConnectorStore";
import {useDialogEditColumn} from "../../../../../../hooks/table_columns/connector_form/useDialogEditColumn";
import {OpcuaConnectorDialogForm} from "./OpcuaConnectorDialogForm";
import {currentUserCan} from "@rx-suite/stores";
import { useConnectorControlActionColumn } from "../../../../../../hooks/table_columns/connector_form/useConnectorControlActionColumn";
import {useConnectorStateColumn} from "../../../../../../hooks/table_columns/connector_form/useConnectorStateColumn";

export const OpcuaConnectorsTab: React.FunctionComponent = observer(({}) => {
    const [dialogModel, setDialogModel] = React.useState<ConnectorModel|null>(null);

    const columns = React.useMemo(() => {
        const cols: Column[] = [
            {Header: t`Name`, accessor: 'name'},
            {
                Header: t`Type`,
                accessor: 'connector_type',
                width: 75
            },
            useConnectorStateColumn(),
            {
                Header: t`Variable`,
                accessor: 'variable',
                width: 110
            },
            {
                Header: t`Priority`,
                accessor: (connector: ConnectorModel) => connector,
                id: 'priority',
                width: 110,
                Cell: (cellInfo: { value: ConnectorModel }) => {
                    if(cellInfo.value.priority === null){
                        return null;
                    }
                    return `${(cellInfo.value.priority)*100}%`;
                }
            },
            {
                Header: t`Action Delay`,
                accessor: (connector: ConnectorModel) => connector,
                id: 'action_delay',
                width: 125,
                Cell: (cellInfo: { value: ConnectorModel }) => {
                    if(!cellInfo.value.action_delay){
                        return null;
                    }
                    return `${cellInfo.value.action_delay} ms`;
                }
            },
            useConnectorControlActionColumn()
        ]

        if(currentUserCan('connector', 'update')){
            cols.push(useDialogEditColumn(setDialogModel));
        }

        return cols;
    }, []);

    return(
        <React.Fragment>
            <ReactTable
                data={ConnectorStore.models}
                columns={columns}
                minRows={ConnectorStore.models.length || 5}
                showPagination={false}
                defaultSorted={[{ id: 'variable', desc: false}]}
                className={'-striped'}
                loading={ConnectorStore.isLoading}
            />
            {
                dialogModel &&
                <OpcuaConnectorDialogForm
                    model={dialogModel}
                    setModel={setDialogModel}
                />
            }
        </React.Fragment>
    )
})