import React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelSelect} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {ModelFormDialog} from "../../../../../../components/generic/ModelFormDialog";
import {DeviceRoutingCommandDeviceStore} from "../../../../../../stores/Device/DeviceRoutingCommandDeviceStore";
import {DeviceStore} from "../../../../../../stores/Device/DeviceStore";
import {ExtraRequirementModel} from "../../../../../../stores/Device/ExtraRequirementStore";
import {ConnectorModel, ConnectorStore} from "../../../../../../stores/ConnectorStore";
import {JobProcessStore} from "../../../../../../stores/machine/JobProcessStore";

type OpcuaSpecialRoutingRuleDialogFormProps = {
    model: ExtraRequirementModel;
    setModel: React.Dispatch<React.SetStateAction<ExtraRequirementModel | null>>
} & Omit<FormProps, 'model'>

export const OpcuaExtraRoutingRuleDialogForm: React.FunctionComponent<OpcuaSpecialRoutingRuleDialogFormProps> = observer(({model, setModel}) => {
    DeviceStore.getAll();
    JobProcessStore.getAll();

    const clonedConnectorStore = React.useMemo(() => {
        return ConnectorStore.clone();
    }, []);

    React.useEffect(() => {
        if(model.viewModel.node_id === null){
            return;
        }

        clonedConnectorStore.refreshData({
            page: 0,
            limit: 20,
            sorted: [],
            filtered: [{id: 'device_id', value: String(model.viewModel.node_id), strictMatchFilter: true}]
        }, true);
    }, [model.viewModel.node_id]);

    const routingCommandOptions = React.useMemo(() => {
        return DeviceRoutingCommandDeviceStore.models.map((command) =>
            ({label: `${command.command_name} ${command.command_parameter}`, value: command.device_routing_command_id})
        );
    }, [DeviceRoutingCommandDeviceStore.models]);

    const deviceOptions = React.useMemo(() => {
        return DeviceStore.models.map((device) => ({label: device.name, value: device.id}));
    }, [DeviceStore.models]);

    const connectorOptions = React.useMemo(() => {
        return (clonedConnectorStore.models as ConnectorModel[])
            .filter(connector => connector.connector_type !== 'other')
            .map((connector) => (
                {label: connector.name, value: connector.id}
            ));

    }, [clonedConnectorStore.models]);

    const jobProcessOptions = React.useMemo(() => {
        const mappedProcesses = JobProcessStore.models.map((jobProcess) => {
            return {label: jobProcess.name, value: jobProcess.id}
        })
        mappedProcesses.push({label: t`Any process`, value: null})
        return mappedProcesses;
    }, [JobProcessStore.models]);

    return (
        <ModelFormDialog
            title={t`Add Extra Routing Rule`}
            model={model}
            setModel={setModel}
        >
            <ModelSelect name={'device_routing_command_id'} options={routingCommandOptions}/>
            <ModelSelect name={'node_id'}
                         options={deviceOptions}
                         loading={DeviceStore.isLoading}
            />
            <ModelSelect name={'connector_id'}
                         options={connectorOptions}
                         loading={clonedConnectorStore.isLoading}
            />
            <ModelSelect name={'job_process_id'}
                         options={jobProcessOptions}
                         loading={JobProcessStore.isLoading}
            />
        </ModelFormDialog>
    )
});
