import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable, {Column} from "react-table";
import {ButtonField, ModelTableDeleteButton, useModelContext} from "@rx-suite/ui";
import {DeviceModel} from "../../../../../../stores/Device/DeviceStore";
import {Box} from "@material-ui/core";
import {ExtraRequirementModel, ExtraRequirementStore} from "../../../../../../stores/Device/ExtraRequirementStore";
import { OpcuaExtraRoutingRuleDialogForm } from "./OpcuaExtraRoutingRuleDialogForm";
import {useDeviceRoutingCommands} from "../../../../../../hooks/device_form/useDeviceRoutingCommands";
import {currentUserCan} from "@rx-suite/stores";

export const OpcuaExtraRoutingRulesTab: React.FunctionComponent = observer(() => {
    const model = useModelContext() as DeviceModel;

    React.useEffect(() => {
        if (model.isNew) {
            return;
        }

        ExtraRequirementStore.refreshData({
            page: 0,
            limit: 20,
            sorted: [],
            filtered: [{id: 'device_id', value: model.getId(), strictMatchFilter: true}]
        });

        useDeviceRoutingCommands(model);
    }, [model])


    const [dialogModel, setDialogModel] = React.useState<ExtraRequirementModel|null>(null);

    const columns = React.useMemo((): Column[] => {
        const cols: Column[] = [
            {Header: t`Trigger on Command`, accessor: 'target_command'},
            {Header: t`Target Device`, accessor: 'target_device'},
            {Header: t`Target Connector`, accessor: 'target_connector'},
            {
                Header: t`On Job Process`,
                accessor: (requirement: ExtraRequirementModel) => requirement,
                id: 'target_process',
                Cell: (cellInfo: { value: ExtraRequirementModel }) => {
                    if(cellInfo.value.target_process !== null) {
                        return cellInfo.value.target_process;
                    }

                    return 'Any Process';
                }
            }
        ]

        if(currentUserCan('ExtraRequirement', 'delete')){
            cols.push({
                accessor: (requirement: ExtraRequirementModel) => requirement,
                id: '_actions',
                style: {textAlign: "right"},
                minWidth: 20,
                Cell: (cellInfo: { value: ExtraRequirementModel }) => {
                    return <ModelTableDeleteButton store={ExtraRequirementStore} model={cellInfo.value}/>
                }
            });
        }

        return cols;
    }, []);

    const handleClickOpen = React.useCallback(() => {
        const reqModel = ExtraRequirementStore.createModel()
        reqModel.viewModel.device_id = model.getId();
        setDialogModel(reqModel);
    }, [setDialogModel]);

    return(
        <React.Fragment>
            <div style={{width: '100%'}}>
                {
                    currentUserCan('ExtraRequirement', 'create') &&
                    <Box mb={1}>
                        <ButtonField
                            text={t`Add a Routing Rule`}
                            onClick={handleClickOpen}
                            variant="outlined"
                            color="secondary"
                        />
                    </Box>
                }
                <ReactTable
                    data={ExtraRequirementStore.models}
                    columns={columns}
                    minRows={ExtraRequirementStore.models.length || 5}
                    showPagination={false}
                    className={'-striped'}
                    loading={ExtraRequirementStore.isLoading}
                />
                {
                    dialogModel &&
                    <OpcuaExtraRoutingRuleDialogForm model={dialogModel} setModel={setDialogModel}/>
                }
            </div>
        </React.Fragment>
    )
})