import React from "react";
import {observer} from "mobx-react-lite";
import {DeviceRoutingCommandDeviceModel, DeviceRoutingCommandDeviceStore} from "../../../../../../stores/Device/DeviceRoutingCommandDeviceStore";
import {useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {DeviceModel} from "../../../../../../stores/Device/DeviceStore";
import ReactTable, {Column} from "react-table";
import {useDeviceRoutingCommands} from "../../../../../../hooks/device_form/useDeviceRoutingCommands";
import { ModelToggleSwitch } from "../../../../../../components/generic/ModelToggleSwitch";
import {useRouterOnline} from "../../../../../../hooks/useRouterOnline";

export const OpcuaRoutingCommandTab: React.FunctionComponent = observer(({}) => {
    const model = useModelContext() as DeviceModel;

    React.useEffect(() => {
        useDeviceRoutingCommands(model);
    }, [model])

    const columns = React.useMemo((): Column[] => {
        return [
            {Header: t`Command`, accessor: 'command_name'},
            {Header: t`Parameter`, accessor: 'command_parameter'},
            {
                Header: t`Enabled`,
                accessor: (command: DeviceRoutingCommandDeviceModel) => command,
                id: 'enabled',
                Cell: (cellInfo: { value: DeviceRoutingCommandDeviceModel }) => {
                    return <ModelToggleSwitch
                        model={cellInfo.value}
                        success={t`Device Routing Command Toggled Successfully`}
                        failure={t`Device Routing Command Failed to Toggle`}
                        disabled={useRouterOnline()}
                    />
                }
            }
        ]
    }, [DeviceRoutingCommandDeviceStore.models])

    return (
        <React.Fragment>
            <ReactTable
                data={DeviceRoutingCommandDeviceStore.models}
                columns={columns}
                minRows={DeviceRoutingCommandDeviceStore.models || 5}
                showPagination={false}
                className={'-striped'}
                loading={DeviceRoutingCommandDeviceStore.isLoading}
            />
        </React.Fragment>
    )
})
