import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable, {Column} from "react-table";
import {ConnectorModel, ConnectorStore} from "../../../../../../stores/ConnectorStore";
import {ScannerStore} from "../../../../../../stores/ScannerStore";
import {SettingStore} from "../../../../../../stores/SettingStore";
import {Grid, LinearProgress} from "@material-ui/core";
import {Check} from "@material-ui/icons";
import {green} from "@material-ui/core/colors";
import {OpcuaScannerDialogForm} from "./OpcuaScannerDialogForm";
import {currentUserCan} from "@rx-suite/stores";
import {useDialogEditColumn} from "../../../../../../hooks/table_columns/connector_form/useDialogEditColumn";

export const OpcuaScannersTab: React.FunctionComponent = observer(() => {
    const settings = SettingStore.selectedModel;
    const [dialogModel, setDialogModel] = React.useState<ConnectorModel|null>(null);

    React.useEffect(() => {
        if(!settings || !settings.use_rx_scanners){
            return;
        }

        ScannerStore.getAll();
    }, [settings])

    const inputs = React.useMemo(() => {
        return ConnectorStore.models.filter(connector => connector.isInput);
    }, [ConnectorStore.models]);

    const columns = React.useMemo(() => {
        const cols: Column[] = [
            {Header: t`Input`, accessor: 'name'},
            {
                Header: t`Has Scanner`,
                accessor: (connector: ConnectorModel) => connector,
                id: 'has_scanner',
                width: 100,
                Cell: (cellInfo: {value: ConnectorModel }) => {
                    if(cellInfo.value.hasScanner){
                        return (
                            <Grid container justifyContent={'center'}>
                                <Check style={{color: green[600]}}/>
                            </Grid>
                        )
                    }
                    return null;
                }
            },
            {
                Header: t`Scanner Tag (OPCUA)`,
                accessor: (connector: ConnectorModel) => connector,
                id: 'opcua_scanner_reference',
                Cell: (cellInfo: {value: ConnectorModel }) => {
                    return cellInfo.value.opcua_scanner_reference;
                }
            },
            {
                Header: t`Retry Attempts`,
                accessor: (connector: ConnectorModel) => connector,
                id: 'scanner_retry',
                Cell: (cellInfo: {value: ConnectorModel }) => {
                    return cellInfo.value.scanner_retry;
                }
            }
        ]

        if(settings?.use_rx_scanners){
            cols.splice(2, 0, {
                    Header: t`Name (Rx-Scanner)`,
                    accessor: (connector: ConnectorModel) => connector,
                    id: 'rx_scanner_reference',
                    Cell: (cellInfo: {value: ConnectorModel }) => {
                        if(cellInfo.value.rx_scanner_reference === null){
                            return null;
                        }

                        if(ScannerStore.isLoading){
                            return <LinearProgress/>;
                        }

                        const scanner = ScannerStore.models.find(scanner=>scanner.id == cellInfo.value.rx_scanner_reference);

                        if(!scanner){
                            return t`unknown`;
                        }

                        return scanner.name;
                    }
                }
            )
        }

        if(currentUserCan('connector', 'update')){
            cols.push(useDialogEditColumn(setDialogModel));
        }

        return cols;
    }, [settings, ScannerStore.models, inputs]);

    return(
        <React.Fragment>
            <ReactTable
                data={inputs}
                columns={columns}
                minRows={inputs.length || 5}
                showPagination={false}
                className={'-striped'}
                loading={ConnectorStore.isLoading}
            />
            {
                dialogModel &&
                <OpcuaScannerDialogForm
                    model={dialogModel}
                    setModel={setDialogModel}
                />
            }
        </React.Fragment>
    )
})