import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable, {Column} from "react-table";
import {useModelContext} from "@rx-suite/ui";
import {DeviceTimerModel, DeviceTimerStore} from "../../../../../../stores/Device/DeviceTimerStore";
import {DeviceModel} from "../../../../../../stores/Device/DeviceStore";
import {OpcuaConstantDialogForm} from "./OpcuaConstantDialogForm";
import {currentUserCan} from "@rx-suite/stores";
import {useDialogEditColumn} from "../../../../../../hooks/table_columns/connector_form/useDialogEditColumn";

export const OpcuaConstantsTab: React.FunctionComponent = observer(() => {
    const model = useModelContext() as DeviceModel;

    const [dialogModel, setDialogModel] = React.useState<DeviceTimerModel|null>(null);

    React.useEffect(() => {
        if (model.isNew) {
            return;
        }

        DeviceTimerStore.refreshData({
            page: 0,
            limit: 20,
            sorted: [],
            filtered: [{id: 'opcua_device_id', value: model.getId(), strictMatchFilter: true}]
        });
    }, [model])

    const columns = React.useMemo((): Column[] => {
        const cols: Column[] = [
            {
                Header: t`Variable`,
                accessor: 'variable',
                width: 150,
            },
            {
                Header: t`Time`,
                accessor: (connector: DeviceTimerModel) => connector,
                id: 'time',
                width: 150,
                Cell: (cellInfo: {value: DeviceTimerModel }) => {
                    return `${cellInfo.value.time} ms`;
                }
            },
            {Header: t`Description`, accessor: 'description'}
        ]

        if(currentUserCan('DeviceTimer', 'update')){
            cols.push(useDialogEditColumn(setDialogModel));
        }

        return cols;
    }, [])

    return(
        <React.Fragment>
            <ReactTable
                data={DeviceTimerStore.models}
                columns={columns}
                minRows={DeviceTimerStore.models.length || 5}
                showPagination={false}
                className={'-striped'}
                loading={DeviceTimerStore.isLoading}
            />
            {
                dialogModel &&
                <OpcuaConstantDialogForm
                    model={dialogModel}
                    setModel={setDialogModel}
                />
            }
        </React.Fragment>
    )
})