import React from "react";
import {FormProps, InputField, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, makeStyles, Typography} from "@material-ui/core";
import {JobFetchProcessInfo, ProcessInfoTable} from "../../components/fetched_job/ProcessInfoTable";
import {grey} from "@material-ui/core/colors";
import {DcsTagsTable, TagData} from "../../components/fetched_job/DcsTagsTable";
import {FetchJobSearchField} from "../../components/fetched_job/FetchJobSearchField";

const useStyles = makeStyles((theme) => ({
    dataSourceLabel: {
        fontSize: '1rem',
        color: grey[500],
        marginBottom: theme.spacing(2)
    }
}));

export const FetchedJobForm: React.FunctionComponent<FormProps> = observer(() => {
    const classes = useStyles();

    const [displayModel, setDisplayModel] = React.useState<FetchedJobData|null>(null)

    return(
        <div>
            <FetchJobSearchField setDataHandler={setDisplayModel}/>
            {displayModel &&
                <PaddedPaper>
                    <Typography variant={'h6'} className={classes.dataSourceLabel}>{`Job Data from ${displayModel?.source}`}</Typography>
                    <ProcessInfoTable processes={displayModel.processes}/>
                    <Box mt={2}>
                        <DcsTagsTable tagData={displayModel.tags}/>
                    </Box>
                </PaddedPaper>
            }
        </div>
    )
});

export type FetchedJobData = {
    job_number: string;
    tags: TagData;
    processes: JobFetchProcessInfo[];
    source : string;
}