import React from "react";
import {FormProps, ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro"
import {RSDModelInput} from "../../components/router_state_dependant_controls/RSDModelInput";
import {JobProcessCapabilitiesTab} from "../../components/job_processes/form/JobProcessCapabilitiesTab";
import {JobProcessConditionsTab} from "../../components/job_processes/form/JobProcessConditionsTab";
import {JobProcessRoutingSettingsTab} from "../../components/job_processes/form/JobProcessRoutingSettingsTab";
import {JobProcessModel} from "../../stores/machine/JobProcessStore";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {Box} from "@material-ui/core";

type JobProcessFormProps = {
    model: JobProcessModel
} & Omit<FormProps, 'model'>

export const JobProcessForm: React.FunctionComponent<JobProcessFormProps> = observer(({model}) => {

    return(
        <ModelForm model={model} suppressMakeCopy={true} suppressImportExport={true}>
            <RSDModelInput model={model} name={'name'}/>
            <RSDModelInput model={model} name={'rank'}/>
            <ModelInput name={'display_name'} hint={{title: t`Display Name`, text: t`This name will be displayed instead of the process name.`}}/>
            {!model.isNew &&
                <Box mt={2}>
                    <TabsContainer tabs={
                            [
                                {
                                    label: t`Capabilities`,
                                    component: <JobProcessCapabilitiesTab/>,
                                    defaultTab: true
                                },
                                {
                                    label: t`Process Condition`,
                                    component:  <JobProcessConditionsTab/>
                                },
                                {
                                    label: t`Routing`,
                                    component: <JobProcessRoutingSettingsTab/>
                                }
                            ]
                        }
                    />
                </Box>
            }
        </ModelForm>
    )
});