import * as React from 'react';
import {BreadModel, makeColumn, ModelTableDeleteButton} from "@rx-suite/ui";
import { t } from "@lingui/macro"
import {JobProcessForm} from "./JobProcessForm";
import {JobProcessStore} from "../../stores/machine/JobProcessStore";
import {observer} from "mobx-react-lite";
import {SettingStore} from "../../stores/SettingStore";
import {useRouterOnline} from "../../hooks/useRouterOnline";

export const JobProcessesBreadModel = observer(() => {
    const settings = SettingStore.selectedModel;

    const columns = React.useMemo(() => {
        return [
            makeColumn('rank', t`Rank`, "string"),
            makeColumn('name', t`Process name`, "string"),
            makeColumn('display_name', t`Display name`, "string"),
        ];
    }, [settings]);

    return (
        <BreadModel store={JobProcessStore}
                    Form={JobProcessForm}
                    columns={columns}
                    tableProps={{
                        showCreateButton: !useRouterOnline(),
                        defaultSorted: [{id: 'rank', desc: false}],
                        replacementActions: {
                            Delete: (row) => {
                                if (row.model.is_control_process) {
                                    return null;
                                }
                                return <ModelTableDeleteButton store={row.store} model={row.model}/>
                            }
                        }
                    }}
        />)
});