import React, {createContext} from "react";
import {PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {MachineNameInput} from "../../components/machines/form/inputs/MachineNameInput";
import {MachineModel} from "../../stores/machine/MachineStore";
import {RejectMachineForm} from "./forms/RejectMachineForm";
import {MesMachineForm} from "./forms/MesMachineForm";
import {MachineTypeSelector} from "../../components/machines/form/inputs/MachineTypeSelector";
import {MachineProcessSelector} from "../../components/machines/form/inputs/JobProcessSelector";
import {VirtualMachineForm} from "./forms/VirtualMachineForm";
import {MachineModelForm} from "../../components/machines/form/MachineModelForm";
import {StartMachineForm} from "./forms/StartMachineForm";
import {ExitMachineForm} from "./forms/ExitMachineForm";

type BaseMachineFormProps = {
    model: MachineModel
}

export const MachineContext = createContext<MachineModel | null>(null);

export const MachineFormRouter: React.FunctionComponent<BaseMachineFormProps> = observer(({model}) => {
    const form = React.useMemo(() => {
        switch(model.viewModel.type) {
            case "MachineMes":
                return <MesMachineForm model={model}/>
            case "MachineReject":
                return <RejectMachineForm model={model}/>
            case "MachineStart":
                return <StartMachineForm model={model}/>
            case "MachineExit":
                return <ExitMachineForm model={model}/>
            case "MachineVirtual":
                return <VirtualMachineForm model={model}/>
        }
    }, [model.viewModel.type])


    if(model.isNew) {
        return(
            <MachineModelForm model={model} suppressMakeCopy suppressImportExport suppressWrapper>
                <MachineTypeSelector/>
                <MachineNameInput/>
                {
                    model.viewModel.type === 'MachineVirtual' &&
                    <MachineProcessSelector/>
                }
            </MachineModelForm>
        )
    }

    return (
        <MachineContext.Provider value={model}>
            {form}
        </MachineContext.Provider>
    )

})
