import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {MachineStore} from "../../stores/machine/MachineStore";
import {observer} from "mobx-react-lite";
import {useMachineCapabilitiesColumn} from "../../hooks/table_columns/machine_bread/useMachineCapabilitiesColumn";
import {useEffect} from "react";
import {MachineStateColorStore} from "@rx-suite/stores";
import {MesMachineCreateButton} from "../../components/machines/bread_model/MesMachineCreateButton";
import {useMachineStateColumn} from "../../hooks/table_columns/machine_bread/useMachineStateColumn";
import {MachineFormRouter} from "./MachineFormRouter";
import {useMachineProcessColumn} from "../../hooks/table_columns/machine_bread/useMachineProcessColumn";

export const MesMachinesBreadModel = observer(() => {
    MachineStateColorStore.getAll();

    useEffect(() => {
        MachineStore.subscribe_machine_state_update(MachineStore.tableIDs);
        return () => {
            MachineStore.unsubscribe();
        }
    }, [MachineStore.tableIDs]);

    const columns = [
        makeColumn('sn', t`Serial number`, "string"),
        makeColumn('name', t`Machine name`, "string"),
        useMachineProcessColumn(),
        useMachineCapabilitiesColumn(),
        useMachineStateColumn()
    ];

    return (
        <BreadModel
            store={MachineStore}
            Form={MachineFormRouter}
            columns={columns}
            tableProps={
                {
                    showCreateButton: false,
                    defaultSorted: [{id: 'job_process.rank', desc: false}],
                    defaultFiltered: [{id: 'rx_data_id', value: 'is not null', strictMatchFilter: true}],
                    pageSize: 100,
                    preTableActions: <MesMachineCreateButton/>,
                    rememberFetchParams: false
                }
            }

        />
    )
})