import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {MachineStore} from "../../stores/machine/MachineStore";
import {CapabilityStore} from "../../stores/machine/CapabilityStore";
import {observer} from "mobx-react-lite";
import {useMachineCapabilitiesColumn} from "../../hooks/table_columns/machine_bread/useMachineCapabilitiesColumn";
import {MachineFormRouter} from "./MachineFormRouter";
import {useMachineStateColumn} from "../../hooks/table_columns/machine_bread/useMachineStateColumn";
import {useMachineProcessColumn} from "../../hooks/table_columns/machine_bread/useMachineProcessColumn";
import {SettingStore} from "../../stores/SettingStore";

export const VirtualMachinesBreadModel = observer(() => {
    const store = React.useMemo(() => {
        if(SettingStore.selectedModel && SettingStore.selectedModel.use_rx_data_machines){
            const specialProcessesStore = MachineStore.clone();
            specialProcessesStore.routingInfo = {
                list: '/special_processes',
                create: '/special_processes/create',
                update: '/special_processes/:id/edit'
            }
            return specialProcessesStore;
        }

        return MachineStore;
    }, [SettingStore.selectedModel]);

    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Machine name`, "string"),
            useMachineProcessColumn(),
            useMachineCapabilitiesColumn(),
            useMachineStateColumn()
        ]

    }, [CapabilityStore.models]);

    return (
        <BreadModel
            store={store}
            Form={MachineFormRouter}
            columns={columns}
            tableProps={
                {
                    defaultSorted: [{id: 'job_process.rank', desc: false}],
                    defaultFiltered: [{id: 'rx_data_id', value: 'is null', strictMatchFilter: true}],
                    pageSize: 100,
                    rememberFetchParams: false
                }
            }
        />
    )
});