import {ModelInput, ModelProvider, PaddedPaper, TabsContainer} from "@rx-suite/ui";
import {MachineNameInput} from "../../../components/machines/form/inputs/MachineNameInput";
import React from "react";
import {observer} from "mobx-react-lite";
import {MachineModel} from "../../../stores/machine/MachineStore";
import {MachineModelForm} from "../../../components/machines/form/MachineModelForm";
import {t} from "@lingui/macro";
import {MachineForceStateSelector} from "../../../components/machines/form/inputs/MachineForceStateSelector";
import {Box} from "@material-ui/core";
import {MachineProcessSettingsTab} from "./form_tabs/MachineProcessSettingsTab";
import {MachineCapabilitiesSettingsTab} from "./form_tabs/MachineCapabilitiesSettingsTab";
import {MachineProcessSelector} from "../../../components/machines/form/inputs/JobProcessSelector";
import {MachineStateSettingsTab} from "./form_tabs/MachineStateSettingsTab";
import {MachineOtherSettingsTab} from "./form_tabs/MachineOtherSettingsTab";
import {SetMachineVirtualButton} from "../../../components/machines/form/SetMachineVirtualButton";

type MesMachineFormProps = {
    model: MachineModel
}

export const MesMachineForm: React.FunctionComponent<MesMachineFormProps> = observer(({model}) => {

  return (
      <React.Fragment>
          <MachineModelForm model={model} suppressMakeCopy suppressImportExport suppressWrapper>
              <SetMachineVirtualButton/>
              <ModelInput name={'sn'} disabled={true}/>
              <MachineNameInput/>
              <MachineProcessSelector/>
              <MachineForceStateSelector/>
          </MachineModelForm>
          <Box mt={1}>
              <ModelProvider value={model}>
                  <PaddedPaper>
                      <TabsContainer tabs={[
                          {
                              label: t`Process Settings`,
                              component: <MachineProcessSettingsTab/>
                          },
                          {
                              label: t`Capabilities`,
                              component: <MachineCapabilitiesSettingsTab/>
                          },
                          {
                              label: t`Machine States`,
                              component: <MachineStateSettingsTab/>
                          },
                          {
                              label: t`Other Settings`,
                              component: <MachineOtherSettingsTab/>
                          }
                      ]
                      }/>
                  </PaddedPaper>
              </ModelProvider>
          </Box>
      </React.Fragment>
  )
})