import React from "react";
import {observer} from "mobx-react-lite";
import {MachineModel} from "../../../stores/machine/MachineStore";
import {ModelProvider, PaddedPaper, TabsContainer} from "@rx-suite/ui";
import {MachineNameInput} from "../../../components/machines/form/inputs/MachineNameInput";
import {MachineTypeSelector} from "../../../components/machines/form/inputs/MachineTypeSelector";
import {MachineModelForm} from "../../../components/machines/form/MachineModelForm";
import {MachineForceStateSelector} from "../../../components/machines/form/inputs/MachineForceStateSelector";
import {t} from "@lingui/macro";
import {RejectFiltersTab} from "./form_tabs/RejectFiltersTab";
import {Box, LinearProgress} from "@material-ui/core";
import {SettingModel, SettingStore} from "../../../stores/SettingStore";

type RejectMachineFormProps = {
    model: MachineModel
}

export const RejectMachineForm: React.FunctionComponent<RejectMachineFormProps> = observer(({model}) => {
    const setting = SettingStore.selectedModel as SettingModel;

    if(!setting){
        return <LinearProgress/>
    }

    return(
        <React.Fragment>
            <MachineModelForm model={model} suppressMakeCopy suppressImportExport suppressWrapper>
                <MachineTypeSelector disabled={true}/>
                <MachineNameInput/>
                <MachineForceStateSelector/>
            </MachineModelForm>
            {
                setting.use_rx_data_machines &&
                <Box mt={1}>
                    <ModelProvider value={model}>
                        <PaddedPaper>
                            <TabsContainer tabs={[
                                    {
                                        label: t`Reject Filters`,
                                        component: <RejectFiltersTab/>
                                    }
                                ]
                            }/>
                        </PaddedPaper>
                    </ModelProvider>
                </Box>
            }
        </React.Fragment>
    )
})