import React from "react";
import {observer} from "mobx-react-lite";
import {MachineModel} from "../../../stores/machine/MachineStore";
import {ModelInput, ModelProvider, PaddedPaper, TabsContainer} from "@rx-suite/ui";
import {MachineNameInput} from "../../../components/machines/form/inputs/MachineNameInput";
import {MachineProcessSelector} from "../../../components/machines/form/inputs/JobProcessSelector";
import {MachineModelForm} from "../../../components/machines/form/MachineModelForm";
import {MachineTypeSelector} from "../../../components/machines/form/inputs/MachineTypeSelector";
import {MachineForceStateSelector} from "../../../components/machines/form/inputs/MachineForceStateSelector";
import {Box} from "@material-ui/core";
import {t} from "@lingui/macro";
import {MachineProcessSettingsTab} from "./form_tabs/MachineProcessSettingsTab";
import {MachineCapabilitiesSettingsTab} from "./form_tabs/MachineCapabilitiesSettingsTab";

type VirtualMachineFormProps = {
    model: MachineModel
}

export const VirtualMachineForm: React.FunctionComponent<VirtualMachineFormProps> = observer(({model}) => {

    return(
        <React.Fragment>
            <MachineModelForm model={model} suppressMakeCopy suppressImportExport suppressWrapper>
                <MachineTypeSelector disabled={true}/>
                {model.sn != null && <ModelInput name={'sn'} disabled={true}/>}
                <MachineNameInput/>
                <MachineProcessSelector/>
                <MachineForceStateSelector/>
            </MachineModelForm>
            <Box mt={1}>
                <ModelProvider value={model}>
                    <PaddedPaper>
                        <TabsContainer tabs={[
                            {
                                label: t`Process Settings`,
                                component: <MachineProcessSettingsTab/>
                            },
                            {
                                label: t`Capabilities`,
                                component: <MachineCapabilitiesSettingsTab/>
                            }
                        ]}
                        />
                    </PaddedPaper>
                </ModelProvider>
            </Box>
        </React.Fragment>
    )
})