import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {Warning} from "@material-ui/icons";
import {useCallback, useMemo} from "react";
import {CapabilityMachineModel, CapabilityMachineStore} from "../../../../stores/machine/CapabilityMachineStore";
import {AssociatedModelTable, useModelContext, makeColumn} from "@rx-suite/ui";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {MachineCapabilityDialog} from "../../../../components/machines/form/MachineCapabilityDialog";
import {CapabilityStore} from "../../../../stores/machine/CapabilityStore";
import {ModelToggleSwitch} from "../../../../components/generic/ModelToggleSwitch";

const useStyles = makeStyles((theme) => ({
    warning: {
        marginRight: '5px'
    },
}));
export const MachineCapabilitiesSettingsTab: React.FunctionComponent = observer(() => {
    const model  = useModelContext() as MachineModel;
    const classes = useStyles();

    const columns = useMemo(() => {
        return [
            makeColumn('capability_name', t`Capability`, 'string'),
            {
                Header: t`Enabled`,
                accessor: (model: CapabilityMachineModel) => model,
                id: 'enabled',
                Cell: (cellInfo: { value: CapabilityMachineModel }) => {
                    if(cellInfo.value.isNew) { return null; }

                    return <ModelToggleSwitch
                        model={cellInfo.value}
                        success={`${t`Capability Toggled`}`}
                        failure={`${t`Failed to Toggle Capability`}`}
                        noSnackBar
                    />
                }
            }
        ]
    }, [])

    const beforeOpenCB = useCallback(() => {
        if(!model.viewModel.job_process_id) { return; }

        CapabilityStore.refreshData({
            filtered: [{id: 'job_process_id', value: model.viewModel.job_process_id.toString(), strictMatchFilter: true}],
            sorted: CapabilityStore.fetchParams.sorted,
            page: CapabilityStore.fetchParams.page,
            limit: CapabilityStore.fetchParams.limit,
        })
    }, [model.viewModel.job_process_id])

    if(!model.viewModel.job_process_id) {
        return <Grid container alignItems="center">
            <Warning className={classes.warning}/><Typography variant={'h6'}><Trans>Please select a process before selecting capabilities</Trans></Typography>
        </Grid>
    }

    return <AssociatedModelTable
        baseModel={model}
        columns={columns}
        associatedColumnName={'capabilities_to_add'}
        DialogForm={MachineCapabilityDialog}
        dialogTitle={t`Add Capability`}
        store={CapabilityMachineStore}
        suppressWrapper
        defaultFiltered={[{id: 'machine_id', value: model.getId(), strictMatchFilter: true}]}
        pageSize={5}
        replacementActions={
            {
                Read: () => null,
                Edit: () => null
            }
        }
        noLinkColumns={['enabled', 'capability_name']}
        handleOpenBeforeActions={beforeOpenCB}
    />
});
