import * as React from "react";
import {observer} from "mobx-react-lite";
import {AssociatedModelTable, useModelContext} from "@rx-suite/ui";
import {MesMachineStateStore} from "../../../../stores/machine/MesMachineStateStore";
import {t} from "@lingui/macro";
import {MesMachineStateDialogComponent} from "../../../../components/machines/MesMachineStateDialogComponent";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {Typography} from "@material-ui/core";
import {CheckCircle, RadioButtonUnchecked} from "@material-ui/icons";
import {green, red} from "@material-ui/core/colors";

export const MachineStateSettingsTab: React.FunctionComponent = observer(() => {
    const model  = useModelContext() as MachineModel;

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Name`,
                accessor: 'name',
                filterable: false,
                sortable: false,
                Cell: (cellInfo: { value: string }) => {
                    return <Typography>{cellInfo.value}</Typography>
                }
            },
            {
                Header: t`Online State?`,
                accessor: 'online',
                filterable: false,
                sortable: false,
                Cell: (cellInfo: { value: boolean }) => {
                    return cellInfo.value ?
                        <CheckCircle style={{color: green[500]}}/> :
                        <RadioButtonUnchecked style={{color: red[500]}}/>
                }
            }
        ]
    }, []);

    return (
        <AssociatedModelTable
            suppressWrapper
            baseModel={model}
            associatedColumnName={'mes_machine_states_to_add'}
            columns={columns}
            DialogForm={MesMachineStateDialogComponent}
            store={MesMachineStateStore}
            defaultFiltered={[{id: 'machine_mes_id', value: model.getId(), strictMatchFilter: true}]}
            replacementActions={
                {
                    Read: () => null
                }
            }
        />
    );
});
