import { observer } from "mobx-react-lite";
import { Column } from "react-table";
import React, { useMemo } from "react";
import {DataStore, Model} from "@rx-suite/data";
import {RejectFilterStore} from "../../../../stores/RejectFilterStore";
import {t} from "@lingui/macro";
import {makeColumn, ModelDialogTable, ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";

export const RejectFiltersTab: React.FunctionComponent = observer(() => {
    const model  = useModelContext();

    const columns: Column[] = useMemo(() => {
        return [
            makeColumn('reject_key', t`Reject Key`, 'string'),
            makeColumn('comment_regex', t`Comment Regex`, 'string')
        ]
    }, [])

    const dialogForm = (m: Model) => {
        m.nestedAssignment('machine_id', model.getId());
        return <React.Fragment>
            <ModelSelect name={'reject_key'} options={[
                {label: 'processAborted', value: 0}
            ]}/>
            <ModelInput name={'comment_regex'}/>
        </React.Fragment>
    }

    return (
        <ModelDialogTable
            store={RejectFilterStore as unknown as DataStore<Model>}
            dialogProps={{
                dialogTitle: t`Reject Filter`,
                dialogForm: dialogForm
            }}
            columns={columns}
            tableProps={{
                defaultPageSize: 5,
                pageSizeOptions: [5, 10, 50],
                defaultFiltered: [{id: 'machine_id', value: model.getId(), strictMatchFilter: true}]
            }}
        />
    )
})
