import * as React from 'react';
import {BreadModel, BreadModelListBadge, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {OrderModel, OrderStore} from "../../stores/OrderStore";
import {Check, WarningOutlined} from "@material-ui/icons";
import {green, grey, red} from "@material-ui/core/colors";
import {OrderViewWorkstation} from "./workstations/view/OrderViewWorkstation";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";

const useStyles = makeStyles((theme) => ({
    rejectWrap: {
        color: red[900],
        margin: '1px',
        padding: '2px 4px',
        borderRadius: '3px',
        backgroundColor: grey[300],
        width: 'fit-content',
    },
    rejectIcon: {
        fontSize: '1.25rem',
        marginRight: theme.spacing(0.25)
    }
}));

export const OrdersBreadModel = observer(() => {
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;
    const classes = useStyles();

    const columns = React.useMemo(() => {
        return [
            makeColumn('number', t`Order number`, "string"),
            {
                id: 'location',
                Header: t`Last Location`,
                accessor: (order: OrderModel) => order,
                sortable: false,
                filterable: false,
                Cell: (cellInfo: { value: OrderModel }) => {
                    const order = cellInfo.value;

                    if(!order.location){
                        return null;
                    }

                    return (
                        <Grid container>
                            <Typography style={{marginRight: '4px'}} variant={'body2'}>{order.location}</Typography>
                            <Typography style={{color: grey[500]}} variant={'body2'}>{`at ${settings.printTime(order.location_time)}`}</Typography>
                        </Grid>
                    )
                }
            },
            {
                id: 'reject_reason',
                Header: t`Reject`,
                width: 300,
                accessor: (order: OrderModel) => order,
                sortable: false,
                filterable: false,
                Cell: (cellInfo: { value: OrderModel }) => {
                    const order = cellInfo.value;

                    if(!order.reject_reason){
                        return null;
                    }

                    return (
                        <Grid container className={classes.rejectWrap}>
                            <WarningOutlined className={classes.rejectIcon}/>
                            <Typography variant={'body2'}>{order.reject_reason}</Typography>
                        </Grid>
                    )
                }
            },
            {
                id: 'is_routing',
                Header: t`Routing`,
                width: 80,
                accessor: (order: OrderModel) => order,
                sortable: false,
                filterable: false,
                Cell: (cellInfo: { value: OrderModel }) => {
                    if(!cellInfo.value.is_routing){
                        return null;
                    }

                    return (
                        <Grid container justifyContent={'center'}>
                            <Check style={{color: green[500]}} />
                        </Grid>
                    )
                }
            }
        ]
    }, [settings]);

    return (
        <BreadModel
            store={OrderStore}
            Form={OrderViewWorkstation}
            columns={columns}
            tableProps={
                {
                    pageSize: 25
                }
            }
        />
    );
}, []);