import React, {useEffect, useState} from "react";
import {FormProps} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {LinearProgress} from "@material-ui/core";
import {DeviceModel, DeviceStore} from "../../stores/Device/DeviceStore";
import {ConnectorModel, ConnectorStore} from "../../stores/ConnectorStore";
import {RouteApplication} from "./RouteApplication";
import {BodyWidgetComponent} from "../../react-diagrams-helpers/BodyWidgetComponent";
import {MachineModel, MachineStore} from "../../stores/machine/MachineStore";
import {RoutingGraphModel, RoutingGraphStore} from "../../stores/RoutingGraphStore";
import { Prompt } from "react-router-dom";
import { t } from "@lingui/macro";
import {ComponentStore} from "../../stores/ComponentStore";

export const RouteBuilder: React.FunctionComponent<FormProps> = observer(({model}) => {
    const [app, setApp] = useState<any>(null);

    const deviceStore = React.useMemo(() => {
        const store = DeviceStore.clone();
        return store;
    }, []);

    const connectorStore = React.useMemo(() => {
        const store = ConnectorStore.clone();
        return store;
    }, []);

    const machineStore = React.useMemo(() => {
        const store = MachineStore.clone();
        return store;
    }, []);

    ComponentStore.getAll(); // underlying components uses this

    const devices = deviceStore.getAll() as DeviceModel[];
    const connectors = connectorStore.getAll() as ConnectorModel[];
    const machines = machineStore.getAll() as MachineModel[];
    const routingGraph = RoutingGraphStore.selectedModel as RoutingGraphModel;

    useEffect(() => {
        setApp(new RouteApplication(routingGraph));
    }, [routingGraph])

    if(deviceStore.isLoading || machineStore.isLoading || connectorStore.isLoading || ComponentStore.isLoading || !routingGraph || !app) {
        return <LinearProgress/>
    }

    const nodes = [];
    for(let i = 0; i < devices.length; i++){
        const device = devices[i];

        const deviceConnectors = connectors.filter((connector) => connector.component_id === device.component_id);
        const node = {
            id: device.component_id,
            inputs: deviceConnectors.filter((connector) => connector.connector_type === 'input'),
            outputs: deviceConnectors.filter((connector) => connector.connector_type === 'output'),
            type: 'device',
            name: device.name
        }
        nodes.push(node);
    }

    for(let i = 0; i < machines.length; i++) {
        const machine = machines[i];
        const machineConnectors = connectors.filter((connector) => connector.component_id === machine.component_id);
        const node = {
            id: machine.component_id,
            inputs: machineConnectors.filter((connector) => connector.connector_type === 'input'),
            outputs: machineConnectors.filter((connector) => connector.connector_type === 'output'),
            type: 'machine',
            name: machine.name
        }
        nodes.push(node);
    }

    return(
        <div>
            <Prompt message={t`Unsaved changes will not be saved, really leave?`} when={true}/>
            <BodyWidgetComponent app={app} preProcessedNodes={nodes} routingGraph={routingGraph}/>
        </div>
    )
});