import React from "react";
import {FormProps, ModelProvider, ModelSubmitButton, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingStore} from "../../stores/SettingStore";
import {LinearProgress} from "@material-ui/core";
import {JobDataSettingsTab} from "./tabs/JobDataSettingsTab";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {PlcConnectionSettingsTab} from "./tabs/PlcConnectionSettingsTab";
import {RoutingSettingsTab} from "./tabs/RoutingSettingsTab";
import {RouterOnlineAlert} from "../../components/router/RouterOnlineAlert";

export const SettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const model = SettingStore.selectedModel

    if (!model) {
        return <LinearProgress color={'secondary'}/>
    }

    return (
        <ModelProvider value={model}>
            <PaddedPaper>
                <RouterOnlineAlert/>
                <TabsContainer tabs={[
                    {
                        label: t`Job Data`,
                        component: <JobDataSettingsTab/>,
                        defaultTab: true
                    },
                    {
                        label: t`PLC Connection`,
                        component: <PlcConnectionSettingsTab/>
                    },
                    {
                        label: t`Routing`,
                        component: <RoutingSettingsTab/>
                    }
                ]}
                />
                <ModelSubmitButton/>
            </PaddedPaper>
        </ModelProvider>
    )
});