import * as React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, ModelCheckbox, ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";
import {SettingModel} from "../../../stores/SettingStore";
import {Box} from "@material-ui/core";
import { useRouterOnline } from "../../../hooks/useRouterOnline";

export const PlcConnectionSettingsTab: React.FunctionComponent = observer(() => {
    const settings = useModelContext() as SettingModel;

    const mopRequestFormat = () => {
        return [
            {label: 'JSON', value: 'JSON'},
            {label: 'XML', value: 'XML'}
        ]
    }

    if(settings.plcIsOpcua){
        return (
            <React.Fragment>
                <ModelInput name={'connection_type'} disabled={true}/>
                <ModelInput name={'variant'} disabled={true}/>
                <ModelInput name={'opcua_server_url'} disabled={useRouterOnline()}/>
                <Conditional condition={settings.variantRequiresBasePath} >
                    <ModelInput name={'device_root_path'}
                                hint={
                                        {
                                            title: 'Device Root Node Id',
                                            text: 'The address of the immediate OPC UA node that contains all other devices. Ex: ns=2;s=MES.PLC1.SLMES'
                                        }
                                }
                                disabled={useRouterOnline()}
                    />
                </Conditional>
                <Box>
                    <ModelCheckbox name={'use_rx_scanners'}
                                   disabled={useRouterOnline()}
                    />
                </Box>
            </React.Fragment>
        )
    }else {
        return (
            <React.Fragment>
                <ModelInput name={'connection_type'} disabled={true}/>
                <ModelSelect name={'data_format'} options={mopRequestFormat()}/>
            </React.Fragment>
        )
    }
});
