import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingModel} from "../../../stores/SettingStore";
import {CheckboxField, ModelCheckbox, ModelInput, useModelContext} from "@rx-suite/ui";
import {Box} from "@material-ui/core";

export const RoutingSettingsTab: React.FunctionComponent = observer((props) => {
    const settings = useModelContext() as SettingModel;

    const [markDeadJobs, setMarkDeadJobs] = React.useState(settings.mark_job_dead_after_x_visit > 0);
    const handleChangeMarkDeadJobs = (e) => {
        if(!e.target.checked){
            settings.viewModel.mark_job_dead_after_x_visit = -1;
        }else{
            if(settings.viewModel.mark_job_dead_after_x_visit === -1){
                settings.viewModel.mark_job_dead_after_x_visit = 10;
            }
        }
        setMarkDeadJobs(e.target.checked)
    }

    return (
        <React.Fragment>
            <ModelInput name={'routing_level'} disabled={true}/>
            <ModelCheckbox name={'loop_load_balancing_enabled'}/>
            <Box>
                <CheckboxField
                    label={t`Reject Dead Jobs`}
                    checked={markDeadJobs}
                    onChange={handleChangeMarkDeadJobs}
                    hint={
                        {
                            title: t`Reject Dead Jobs`,
                            text: t`Reject jobs that have visited the same decision point too many time. This setting can be used to catch jobs stuck in a loop.`
                        }
                    }
                />
            </Box>
            <ModelInput
                label={t`Mark Dead After X Visits`}
                name={'mark_job_dead_after_x_visit'}
                hidden={!markDeadJobs}
            />
            <ModelCheckbox name={'launch_server_on_service_start'}/>
        </React.Fragment>
    );
});
