import React from "react";
import {Conditional, FormProps, ModelForm} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Trans} from "@lingui/macro";
import {Alert} from "@material-ui/lab";
import {TagModel} from "../../stores/TagStore";
import {TagFormBody} from "../../components/tags/TagFormBody";

type TagFormProps = {
    model: TagModel
} & Omit<FormProps, 'model'>

export const TagForm: React.FunctionComponent<TagFormProps> = observer(({model}) => {
    return(
        <ModelForm model={model} suppressMakeCopy suppressImportExport readOnly={model.system_tag}>
            <Conditional condition={model.system_tag}>
                <Alert severity="info">
                    <Trans>This is a system generated tag and cannot be edited.</Trans>
                </Alert>
            </Conditional>
            <TagFormBody/>
        </ModelForm>
    )
});