import { Action, ActionEvent, InputType, State } from '@projectstorm/react-canvas-core';
import { PortModel, LinkModel, DiagramEngine } from '@projectstorm/react-diagrams-core';
import { MouseEvent, KeyboardEvent } from 'react';

/**
 * This state is controlling the creation of a link.
 */
export class CreateComponentLinkState extends State<DiagramEngine> {
    sourcePort: PortModel;
    link: LinkModel;

    constructor() {
        super({name: 'create-new-link'});

        this.registerAction(
            new Action({
                type: InputType.MOUSE_UP,
                fire: (actionEvent: ActionEvent<MouseEvent>) => {
                    if (this.engine.getModel().isLocked()) return;
                    const element = this.engine.getActionEventBus().getModelForEvent(actionEvent);
                    const ox = this.engine.getModel().getOffsetX();
                    const oy = this.engine.getModel().getOffsetY();

                    if (element instanceof PortModel && !this.sourcePort) {
                        const {
                            event: { clientX, clientY }
                        } = actionEvent;
                        const model = this.engine.getModel();
                        this.sourcePort = element;

                        const link = this.sourcePort.createLinkModel();
                        link.setSourcePort(this.sourcePort);
                        const portPos = this.sourcePort.getPosition();
                        link.getFirstPoint().setPosition(portPos.x, portPos.y + (element.height / 2) * (model.getZoomLevel() / 100));
                        link.getLastPoint().setPosition(portPos.x + 20, portPos.y + (element.height / 2) * (model.getZoomLevel() / 100));

                        this.link = this.engine.getModel().addLink(link);
                    } else if (element instanceof PortModel && this.sourcePort && element != this.sourcePort) {
                        if (this.sourcePort.canLinkToPort(element)) {
                            this.link.setTargetPort(element);
                            element.reportPosition();
                            this.clearState();
                            this.eject();
                        }
                    }
                    //This is the create a point when the link is clicked outside of a port. doesnt work well with rightAngle
                    else {
                        this.link.remove();
                        this.clearState();
                        this.eject();
                    }

                    this.engine.repaintCanvas();
                }
            })
        );

        this.registerAction(
            new Action({
                type: InputType.MOUSE_MOVE,
                fire: (actionEvent: ActionEvent<React.MouseEvent>) => {
                    if (this.engine.getModel().isLocked()) return;
                    if (!this.link) return;
                    const ox = this.engine.getModel().getOffsetX();
                    const oy = this.engine.getModel().getOffsetY();
                    const zoom = this.engine.getModel().getZoomLevel() / 100.0;
                    const canvas = this.engine.getCanvas();
                    const rect = canvas.getBoundingClientRect();
                    const {event} = actionEvent;
                    const x = (event.clientX - rect.left - ox) / zoom;
                    const y = (event.clientY - rect.top - oy) / zoom;
                    this.link.getLastPoint().setPosition(x, y);
                    this.engine.repaintCanvas();
                }
            })
        );

        this.registerAction(
            new Action({
                type: InputType.KEY_UP,
                fire: (actionEvent: ActionEvent<KeyboardEvent>) => {
                    // on esc press remove any started link and pop back to default state
                    if (actionEvent.event.keyCode === 27 || actionEvent.event.keyCode === 46) {
                        this.link.remove();
                        this.clearState();
                        this.eject();
                        this.engine.repaintCanvas();
                    }
                }
            })
        );
    }

    clearState() {
        this.link = undefined;
        this.sourcePort = undefined;
    }
}