import {DefaultPortModel, LinkModel, RightAngleLinkModel, PortModelOptions, PortModelGenerics, PortModelAlignment} from "@projectstorm/react-diagrams";
import {AbstractModelFactory} from "@projectstorm/react-canvas-core";

export interface RightAnglePortModelOptions extends PortModelOptions {
	label?: string;
	in?: boolean;
}

export class RightAnglePortModel extends DefaultPortModel {
	constructor(isIn: boolean, name: string, label?: string)
	constructor(options: RightAnglePortModelOptions);
	constructor(options: RightAnglePortModelOptions | boolean, name?: string, label?: string) {
		if (!!name) {
			options = {
				in: !!options,
				name: name,
				label: label
			};
		}
		options = options as RightAnglePortModelOptions;
		super({
			label: options.label || options.name,
			alignment: options.in ? PortModelAlignment.LEFT : PortModelAlignment.RIGHT,
			type: 'rightAngle',
			maximumLinks: 99,
			...options
		});
	}

	createLinkModel(factory?: AbstractModelFactory<LinkModel>) {
		return new RightAngleLinkModel();
	}

	canLinkToPort(port: RightAnglePortModel): boolean {
		if(Object.keys(port.getLinks()).length >= port.getMaximumLinks()) {
			return false
		}
		if(Object.keys(this.getLinks()).length > this.getMaximumLinks()) {
			return false
		}
		if(port.getNode().getID() === this.getNode().getID()) {
			return false
		}
		if(port.getOptions().in === this.getOptions().in){
			return false
		}
		return true
	}
}