import {dataStorePermission} from "@rx-suite/ui";
import {
    Settings,
    AssignmentReturned,
    DeviceHub,
    Label,
    ImportExport,
    SlowMotionVideo,
    List,
    Build,
    AddCircle, BuildRounded
} from '@material-ui/icons';
import MemoryIcon from '@material-ui/icons/Memory';
import {DeviceTypeStore} from "./stores/Device/DeviceTypeStore";
import {DeviceTypesBreadModel} from "./pages/device_types/DeviceTypesBreadModel";
import {SettingStore} from "./stores/SettingStore";
import {MachineStore} from "./stores/machine/MachineStore";
import {DeviceStore} from "./stores/Device/DeviceStore";
import {JobProcessesBreadModel} from "./pages/job_processes/JobProcessesBreadModel";
import {CapabilitiesBreadModel} from "./pages/capabilities/CapabilitiesBreadModel";
import {RoutingGraphStore} from "./stores/RoutingGraphStore";
import {TagStore} from "./stores/TagStore";
import {TagsBreadModel} from "./pages/tags/TagBreadModel";
import {SettingForm} from "./pages/settings/SettingForm";
import { t } from "@lingui/macro";
import {RouteBuilder} from "./pages/routes/RouteBuilder";
import {computedFn} from "mobx-utils";
import {FetchedJobForm} from "./pages/fetched_jobs/FetchedJobForm";
import React from "react";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faGlasses} from "@rx-suite/pro-solid-svg-icons/faGlasses";
import {faRandom} from "@rx-suite/pro-solid-svg-icons/faRandom";
import { OrderStore } from "./stores/OrderStore";
import {CommandCenter} from "./pages/command_center/CommandCenter";
import {RouterServerStore} from "./stores/RouterServerStore";
import {OrdersBreadModel} from "./pages/orders/OrdersBreadModel";
import {OrderFindField} from "./components/orders/workstations/view/OrderFindField";
import {OrderCreateWorkstation} from "./pages/orders/workstations/create/OrderCreateWorkstation";
import {DevicesRouter} from "./pages/devices/DevicesRouter";
import {MesMachinesBreadModel} from "./pages/machines/MesMachinesBreadModel";
import {VirtualMachinesBreadModel} from "./pages/machines/VirtualMachinesBreadModel";
import { RedirectToPath } from "./components/generic/RedirectToPath";


const machineRoutes = (): any[] => {
    const settings = SettingStore.selectedModel;
    if(settings?.use_rx_data_machines) {
        return [
            {
                label: t`Machines`,
                Icon: MemoryIcon,
                exact: false,
                to: '/machines',
                permission: dataStorePermission(MachineStore),
                Component: MesMachinesBreadModel
            },
            {
                label: t`Special Processes`,
                to: "/special_processes",
                exact: false,
                permission: dataStorePermission(MachineStore),
                Component: VirtualMachinesBreadModel,
                Icon: BuildRounded
            }
        ]
    } else {
        // In easy routing, all machines are 'virtual', so no need to segment them
        return [
            {
                label: t`Machines`,
                to: "/machines",
                exact: false,
                permission: dataStorePermission(MachineStore),
                Component: VirtualMachinesBreadModel,
                Icon: MemoryIcon
            },
        ]
    }
}

export const getRoutes = computedFn(() => {
    let routes = [
        {
            to: "/",
            exact: true,
            Component: RedirectToPath,
            props: {path: "/job_workstation/jobs"}
        },
        {
            label: t`Command Center`,
            to: "/command_center",
            permission: {
                target: RouterServerStore.permissionTarget as string,
                action: 'read'
            },
            exact: false,
            Icon: SlowMotionVideo,
            Component: CommandCenter
        },
        {
            label: t`Job Workstation`,
            to: "/job_workstation",
            exact: true,
            permission: {
                target: OrderStore.permissionTarget as string,
                action: 'read'
            },
            Icon: () => <FontAwesomeIcon icon={faGlasses} style={{height: '22px', width: '22px'}}/>,
            Component: OrderFindField,
            children: [
                {
                    label: t`All Jobs`,
                    to: "/jobs",
                    exact: false,
                    permission: dataStorePermission(OrderStore),
                    Component: OrdersBreadModel,
                    Icon: List
                },
                {
                    label: t`Job Fetcher`,
                    to: "/fetch",
                    exact: false,
                    Icon: ImportExport,
                    Component: FetchedJobForm
                },
                {
                    label: t`Job Create`,
                    to: "/job_create",
                    exact: false,
                    permission: {
                        target: OrderStore.permissionTarget,
                        action: 'create'
                    },
                    Icon: AddCircle,
                    Component: OrderCreateWorkstation
                }
            ]
        },
        {
            label: t`Devices`,
            to: "/devices",
            exact: false,
            permission: dataStorePermission(DeviceStore),
            Component: DevicesRouter,
            Icon: () => <FontAwesomeIcon icon={faRandom} style={{height: '22px', width: '22px'}}/>
        },
        {
            label: t`Settings`,
            to: "/settings",
            exact: true,
            permission: dataStorePermission(SettingStore),
            Component: SettingForm,
            Icon: Settings,
            children: [
                {
                    label: t`Routing Graph`,
                    to: "/routing_graph",
                    exact: false,
                    permission: dataStorePermission(RoutingGraphStore),
                    Component: RouteBuilder,
                    Icon: DeviceHub
                },
                {
                    label: t`Processes`,
                    to: "/job_processes",
                    exact: false,
                    permission: dataStorePermission(MachineStore),
                    Icon: AssignmentReturned,
                    Component: JobProcessesBreadModel,
                    children: [
                        {
                            to: "/capabilities",
                            exact: false,
                            permission: dataStorePermission(MachineStore),
                            Component: CapabilitiesBreadModel
                        }
                    ]
                },
                {
                    label: t`Tags`,
                    to: "/tags",
                    exact: false,
                    permission: dataStorePermission(TagStore),
                    Component: TagsBreadModel,
                    Icon: Label
                },
                {
                    label: t`Device Types`,
                    to: "/device_types",
                    exact: false,
                    permission: dataStorePermission(DeviceTypeStore),
                    Component: DeviceTypesBreadModel,
                    Icon: Build,
                    shouldMount: () => { return SettingStore.selectedModel ? SettingStore.selectedModel.plcIsOpcua : false }
                }
            ]
        }
    ]

    routes = [
        ...routes.slice(0,4),
        ...machineRoutes(),
        ...routes.slice(4)
    ]

    return routes;
});
