import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {override} from "mobx";

@model({
    transportLayer: "/api/extra_requirements",
    permissionTarget: "ExtraRequirement",
    routingInfo: {
        create: '/extra_requirements/create',
    }
})

export class ExtraRequirementModel extends Model {
    @attribute()
    device_id: string | null = null;

    @attribute({
        label: t`Trigger on Command`,
        validation: yup.number().required().typeError('Trigger on Command is required')
    })
    device_routing_command_id: null | number = null;

    @attribute({
        label: t`Target Device`,
        validation: yup.number().required().typeError('Target Device is required')
    })
    node_id: number | null = null;

    @attribute({
        label: t`Target Connector`,
        validation: yup.number().required().typeError('Target Connector is required')
    })
    connector_id: number | null = null;

    @attribute({
        label: t`Trigger on Process`,
        validation: yup.number().nullable()
    })
    job_process_id: number | null = null;

    @attribute()
    target_command: string = '';

    @attribute()
    target_device: string = '';

    @attribute()
    target_connector: string = '';

    @attribute()
    target_process: string = '';

    @override
    handleSelectChange(name: string | undefined, value: (string | Array<string> | boolean | Array<boolean> | number | Array<number>)) {
        super.handleSelectChange(name, value);

        if(name === 'node_id'){
            this.nestedAssignment('connector_id', null);
        }
    }

    constructor() {
        super();
        super.setup();
    }
}

export const ExtraRequirementStore = ExtraRequirementModel.store as DataStore<ExtraRequirementModel>;
