import {attribute, DataStore, Model, model} from '@rx-suite/data';
import {action, computed} from "mobx";
import moment, { Moment } from "moment";
import {OrderStore} from "./OrderStore";

@model({
    singleton: true,
    transportLayer: "/api/routers",
    permissionTarget: "Router",
    eager: true
})

export class RouterServerModel extends Model {
    @attribute()
    status: RouterState = 'offline';

    @attribute()
    updated_at: Moment = moment();

    @computed
    get running(): boolean {
        return this.status !== 'offline';
    }

    @action async start() {
        const response = await this.store.transportLayer.fetch('/start', {method: "PUT"})
        const data = await response.json();
        return data;
    }

    @action async stop() {
        const response = await this.store.transportLayer.fetch('/stop', {method: "PUT"})
        const data = await response.json();

        // Force the job store to refresh as the backend won't broadcast the job.is_routing false for every job
        OrderStore.getTableData(true);

        return data;
    }

    constructor() {
        super();
        super.setup();
    }
}

type RouterState = 'offline' | 'starting' | 'online' | 'standby' | 'error';

export const RouterServerStore = RouterServerModel.store as DataStore<RouterServerModel>;
