import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

@model({
    transportLayer: "/api/tags",
    permissionTarget: "Tag",
    routingInfo: {
        create: '/settings/tags/create',
        update: '/settings/tags/:id/edit'
    }
})
export class TagModel extends Model {
    @attribute({
        label: t`Tag Name`,
        validation: yup.string().required('Tag Name cannot be blank')
    })
    tag: string | null = null;

    @attribute({
        label: t`Type`
    })
    value_type: 'string' | 'number' = 'string';

    @attribute({
        label: t`Default Value`,
        validation: yup.string().nullable()
    })
    default_value: string | null = null

    @attribute({})
    system_tag: boolean = false;

    constructor() {
        super();
        super.setup();
    }
}

export const TagStore = TagModel.store as DataStore<TagModel>;
