import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {computed} from "mobx";
@model({
    eager: true,
    transportLayer: "/api/capabilities",
    permissionTarget: "Capability",
    routingInfo: {
        create: '/settings/job_processes/capabilities/create',
        read: '/settings/job_processes/capabilities/:id/edit',
        update: '/settings/job_processes/capabilities/:id/edit'
    }
})
export class CapabilitiesModel extends Model {
    @attribute({
        label: t`Capability`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Name`,
        validation: yup.string().required("Field name is required")
    })
    name: string = "";

    @attribute({
        label: t`Machines`,
        validation: yup.array()
    })
    opcua_machine_ids: any = [];

    @attribute({
        label: t`Job Process id`,
        validation: yup.number()
    })
    job_process_id: number = 0;

    @attribute({
        label: t`Condition`,
    })
    condition: any = null;

    @attribute({
        label: t`Display name`,
        validation: yup.string().nullable()
    })
    display_name: string | null = null;

    @attribute({
        label: t`Rank`,
        validation: yup.number().nullable()
    })
    rank: number | null = null;

    @attribute()
    tag_condition_id: string | null = null;

    @computed
    get resolvedName() {
        if(this.display_name){
            return this.display_name;
        }
        return this.name;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const CapabilityStore = CapabilitiesModel.store as DataStore<CapabilitiesModel>;
