import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {computed} from "mobx";
import {number} from "yup";
import {useRouterOnline} from "../../hooks/useRouterOnline";
import {IgnoredAbortReasonModel} from "../IgnoredAbortReasonStore";

type HANDLE_STARTED = 'reject_job' | 'hold_as_current' | 'hold_as_next';
type CAPABILITY_RESOLVE_MODE = 'require_all' | 'highest_rank';

@model({
    eager: true,
    transportLayer: "/api/job_processes",
    permissionTarget: "Machine",
    routingInfo: {
        create: '/settings/job_processes/create',
        update: '/settings/job_processes/:id/edit'
    }
})

export class JobProcessModel extends Model {
    @attribute()
    is_control_process: boolean = false;

    @attribute({
        label: t`Process name`,
        validation: yup.string().required("Name is a required field")
    })
    name: string = "";

    @attribute({
        label: t`Display name`,
        validation: yup.string().nullable()
    })
    display_name: string | null = null;

    @attribute({
        label: t`Rank`,
        validation: number().typeError(t`Rank is a required field`).when('is_control_process',{
            is: false,
            then: schema => schema.min(1).max(999),
            otherwise: schema => schema
        })
    })
    rank: number = 10

    @attribute({
        label: t`Capabilities`,
        validation: yup.array().nullable()
    })
    capability_ids: number[] = [];

    @attribute({
        label: t`Condition`,
    })
    condition: any = null;

    @attribute({
        label: t`Handle Started`,
        validation: yup.string()
    })
    handle_started: HANDLE_STARTED = 'reject_job';

    @attribute({
        label: t`Resolve Capabilities`,
        validation: yup.string()
    })
    capability_resolve_mode: CAPABILITY_RESOLVE_MODE = 'require_all';

    @attribute()
    tag_condition_id: string | null = null;

    @attribute({})
    ignored_abort_reasons_to_add: IgnoredAbortReasonModel[] = [];

    canDelete(): boolean {
        return !useRouterOnline();
    }

    @computed
    get requireCapabilityRank(): boolean {
        return this.viewModel.capability_resolve_mode === 'highest_rank';
    }

    @computed
    get resolvedName() {
        if(this.display_name){
            return this.display_name;
        }
        return this.name;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const JobProcessStore = JobProcessModel.store as DataStore<JobProcessModel>;
