import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

export type States = 'ON' | 'OFF' | 'READY' | 'WAITINGFORJOBS' | 'PROCESSING' | 'NOTREADY' |
    'ERROR' | 'HALT' | 'ESTOP' | 'MAINTENANCE' | 'CALIBRATION' | 'SETUP' | 'NOTCONNECTED'

export const  StateObject = ['ON', 'OFF', 'READY', 'WAITINGFORJOBS', 'PROCESSING', 'NOTREADY', 'ERROR',
    'HALT', 'ESTOP', 'MAINTENANCE', 'CALIBRATION', 'SETUP', 'NOTCONNECTED']

@model({
    transportLayer: '/api/mes_machine_states',
    permissionTarget: "MesMachineState",
    routingInfo: {
        create: '/mes_machine_states/create',
    }
})

export class MesMachineStateModel extends Model {
    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Name`,
        validation: yup.string()
    })
    name: string = "";

    @attribute({
        label: t`Online`,
        validation: yup.boolean()
    })
    online: boolean = true;

    @attribute({
        label: t`Mes machine id`,
        validation: yup.number()
    })
    mes_machine_id: number = 0;

    constructor() {
        super();
        super.setup();
    }
}

export const MesMachineStateStore = MesMachineStateModel.store as DataStore<MesMachineStateModel>;
