module RouterEndpoints
  class UpdateLocationJob < ApplicationJob
    queue_as :router_job_location

    def perform(data)
      order_number = data[:order]
      locations = data[:locations]
      order = Order.find_by(number: order_number)

      return if order.nil?

      Order.transaction do
        locations.each do |location|
          order.order_histories.build({
                                         event_type: :location_update,
                                         data: {
                                           location: location[:location]
                                         }.to_json,
                                         time: location[:time]
                                       })
        end

        latest_location = locations.first
        if latest_location
          if Time.zone.parse(latest_location[:time]) > order[:location_time]
            order.assign_attributes({location: latest_location[:location], location_time: latest_location[:time]})
          end
        end

        order.save!
      end
    end
  end
end