module RouterEndpoints
  class UpdateProcessesJob < ApplicationJob
    queue_as :router_job_processes

    def perform(data)
      order_number = data[:order]
      processes = data[:processes]
      order = Order.find_by(number: order_number)

      return if order.nil?

      Order.transaction do
        update_processes(processes)

        order.order_histories.create({
                                      event_type: :process_update,
                                      data: {
                                        updatedProcesses: processes.map { |process| { processId: process[:id], source: process[:source] }}
                                      }.to_json,
                                      time: Time.zone.now
                                    })
      end
    end

    def update_processes(processes)
      processes.each do |process|
        required_process = RequiredProcess.find_by(id: process[:id])

        next if required_process.nil?
        next if Time.zone.parse(process[:time]) < required_process[:last_state_change_timestamp]


        if process[:logToHistory]
          required_process.required_process_state_histories.build({
                                                                    state: process[:state].upcase,
                                                                    source: process[:source],
                                                                    time: process[:time],
                                                                    comment: process[:lastMachineComment]
                                                                  })
        end

        required_process.update(
          state: process[:state].upcase,
          last_location_received_at: process[:source],
          last_comment: process[:lastMachineComment],
          last_state_change_timestamp: process[:time],
          is_rework: process[:isRework]
        )

        RxModule::WorkerBroadcast.broadcast_later(model: required_process, action: :update, channel_class: RequiredProcessChannel)
      end
    end
  end
end