class ExternalSystems
  class << self
    def broadcast_statuses
      result = ExternalSystems.statuses
      ActionCable.server.broadcast "externalSystemsChannel", result
    end

    def statuses
      pings = []

      if Setting.instance.lms_tag_source?
        LmsConfig.all_job_lms.map do |config|
          pings << cached_ping_result(config.id) do
            ping_lms(config)
          end
        end
      end

      pings.push(cached_ping_result('rx_data') do
       {name: 'rx-data', online: ping_module('rx_data')}
      end) if Setting.instance.use_rx_data?

      pings.push(cached_ping_result('rx-scanners') do
        {name: 'rx-scanners', online: ping_module('rx_scanners')}
      end) if Setting.instance.use_rx_scanners?

      {
        systems: pings,
        updated_at: Time.zone.now
      }
    end

    def overwrite_ping_result(config, data)
      Rails.cache.write([self, config.id],  build_lms_cache_results(config, data), expires_in: 2.minutes)
    end

    private

    def build_lms_cache_results(config, results)
      {
        name: results[:name],
        online: results[:success],
        lms_config_id: config.id
      }
    end

    def cached_ping_result(name)
      Rails.cache.fetch([self, name], expires_in: 2.minutes) do
        yield
      end
    end

    def ping_lms(config)
      res = config.ping
      build_lms_cache_results(config, res)
    end

    def ping_module(module_name)
      RxModule::Communicator.call_module_method(module_name, '/api/rx_module/info', :get,nil,nil, ping_connection)
      true
    rescue => err
      Rails::logger.warn "Failed to ping module #{module_name} - err: #{err}"
      false
    end

    def ping_connection
      client = Faraday.new
      client.options.timeout = 5
      client
    end
  end
end