module OrderRequest
  class OrderNotSelected < StandardError; end

  class OrderRequest
    class << self
      def order_for_number(order_number, request_type)
        ApplicationRecord.quietly do
          request = if request_order_as_new?(order_number, request_type)
                      OrderRequestNew.new
                    else
                      OrderRequestExisting.new
                    end
          do_request(request, order_number)

          request.order
        end
      end

      def force_new_order(order_number)
        request = OrderRequestNew.new

        do_request(request, order_number)

        request.order
      end

      private

      def request_order_as_new?(order_number, request_type)
        return true if request_type == 'new'
        return false if request_type == 'existing'

        # If the request type is 'new_or_existing', request the order has new only if it doesn't exist
        !Order.exists?(number: order_number)
      end

      def do_request(request, order_number)
        request.execute(order_number)

        raise OrderNotSelected if request.order.nil?

        request.order.is_routing = true
        request.order.save!
      end
    end

    attr_accessor :order_number, :order

    def execute(order_number)
      raise NotImplementedError
    end

    def handle_reject_order(data)
      raise OrderNotSelected if @order.nil?

      if ProcessFetcher.use_default_on_fail
        processes = JobProcessCalculator.instance.default_processes
        @order.set_required_processes(processes)
      else
        unless @order.rejected?
          @order.reject(Order.REJECT_REASONS[:failFetchProcesses], Time.zone.now, data)
        end
      end
    end
  end
end