class Component < ApplicationRecord
  validates :name, uniqueness: true
  has_one :machine
  has_one :device
  has_many :connectors, dependent: :destroy

  # Since the models have been created without proper foreign keys and adding them would be difficult, when destroying we need to go and clean up the attached connectors, and attached device or machine
  after_destroy do |component|
    component.machine&.destroy
    component.device&.destroy
    component.connectors.destroy_all
  end

  def self.replace_name_with_component_name(action)
    if action[:id] == "name"
      action[:id] = "component.name"
    end
    action
  end
end