class Connector < ApplicationRecord
  include IsRouterResource

  # optional here because device types have components
  belongs_to :component, :optional => true

  def assign_attributes_from_params(params)
    # Should be implemented by child class
    raise NotImplementedError
  end

  def as_router_data
    # Should be implemented by child class
    raise NotImplementedError
  end

  def ensure_control_action_params(control_actions_params)
    return nil if control_actions_params.nil?

    has_settings = false

    simple_control_actions = [:unreject, :holdReject, :holdStarted, :splitJobsToOutput, :forceFullPathResolve]

    # Check if any simple boolean control actions are set to true
    has_settings = true if simple_control_actions.any? {|key| control_actions_params[key] }

    has_settings = true if control_actions_params[:fetch][:enabled]
    has_settings = true unless control_actions_params[:setProcesses][:process].nil?
    has_settings = true unless control_actions_params[:validateProcesses][:process].nil?
    has_settings = true unless control_actions_params[:addControlProcess][:process].nil?

    if has_settings
      control_actions_params.to_json
    else
      nil # nil the setting if all control actions are off
    end
  end
end