class ExtraRequirement < ApplicationRecord
  belongs_to :device_routing_command
  belongs_to :device

  include IsRouterResource

  concerning :IsRouterResource do
    def as_router_data
      device = Device.find_by(id: node_id)
      connector = Connector.find_by(id: connector_id)
      process = if job_process_id.nil?
                  nil
                else
                  JobProcess.find_by(id: job_process_id)
                end

      return nil if device.nil? || connector.nil?

      {
        identifier: {
          node: device.component.name,
          connector: connector.name
        },
        applyIfJobNextProcessIs: if process.nil?
                                   nil
                                 else
                                   process.name
                                 end
      }
    end
  end

  def device_routing_command_name
    self.device_routing_command[:command] + ' ' + self.device_routing_command[:parameter]
  end

  def node_name
    Device.find(self[:node_id]).component[:name]
  end

  def connector_name
    Connector.find(self[:connector_id])[:name]
  end

  def job_process_name
    if self[:job_process_id].nil?
      nil
    else
      JobProcess.find(self[:job_process_id])[:name]
    end
  end
end
