class JobProcess < ApplicationRecord
  include IsRouterResource

  has_many :machines
  has_many :capabilities, dependent: :destroy
  has_many :required_processes, dependent: :destroy
  has_many :ignored_abort_reasons, dependent: :destroy
  has_one :tag_condition

  enum capability_resolve_mode: [:require_all, :highest_rank]
  enum handle_started: [:reject_job, :hold_as_current, :hold_as_next]

  class << self
    def seed
      JobProcess.new(name: 'start', rank: 0, is_control_process: true).save if JobProcess.find_by_name('start').nil?

      if JobProcess.find_by_name('processed').nil?
        processed_process = JobProcess.new(name: 'processed', rank: 999, is_control_process: true )
        processed_process.capabilities << Capability.new(name: 'accepted')
        processed_process.capabilities << Capability.new(name: 'rejected')
        processed_process.save
      end
    end

    def lteq_rank(rank)
      JobProcess.where(JobProcess.arel_table[:rank].lteq(rank))
    end

    def gteq_rank(rank)
      JobProcess.where(JobProcess.arel_table[:rank].gteq(rank))
    end
  end

  def assign_attributes_from_params(params)
    assign_attributes({
      name: params[:name],
      rank: params[:rank],
      capability_resolve_mode: params[:capability_resolve_mode],
      handle_started: params[:handle_started],
      display_name: params[:display_name]
    })

    unless params[:ignored_abort_reasons_to_add].nil?
      params[:ignored_abort_reasons_to_add].each do |ignored_abort_reason|
        ignored_abort_reasons.build(abort_reason: ignored_abort_reason[:abort_reason])
      end
    end
  end

  def comment_matches_abort_override?(str_to_test)
    return false if str_to_test.nil?
    return false if ignored_abort_reasons.empty?
    ignored_abort_reasons.any? do |ignored_abort_reason|
      Regexp.new(ignored_abort_reason.abort_reason).match?(str_to_test)
    end
  end

  def has_condition?
    return false if tag_condition.nil?
    true
  end

  def is_control_process?
    is_control_process
  end

  def to_json(*args)
    render_jbuilder_partial
  end

  concerning :IsRouterResource do
    def synchronize_payload
      {
        method: :put,
        endpoint: '/process/update',
        data: as_router_data
      }
    end

    def as_router_data
      {
        name: name,
        rank: rank,
        handleStarted: handle_started,
        ignoredAbortReasons: ignored_abort_reasons.map { |ignored_abort_reason| ignored_abort_reason.abort_reason }
      }
    end
  end
end
