class MachineMes < Machine
  has_many :mes_machine_states, dependent: :destroy

  class << self
    def new_from_params(params)
      component = Component.new(name: params[:name])
      mes_machine = component.machine = MachineMes.new(
        rx_data_id: params[:rx_data_id],
        sn: params[:sn],
        apply_process_change_on: 'use_job_state',
        force_duration: 0,
        forced_state: 'use_state'
      )

      mes_machine.build_connectors

      mes_machine.mes_machine_states << MesMachineState.new(name: 'WAITINGFORJOBS', online: true)
      mes_machine.mes_machine_states << MesMachineState.new(name: 'PROCESSING', online: true)

      # Do not call assign_attributes from params as the params come from Rx-Data, not the front-end

      mes_machine
    end
  end

  def controller_name
    "MachinesController"
  end

  def is_sending_job_states?
    apply_process_change_on == 'use_job_state'
  end

  def assign_attributes_from_params(params)
    super

    assign_attributes(
      selected_reject: params[:selected_reject],
      allow_job_start: params[:allow_job_start],
      restart_jobs: params[:restart_jobs],
      apply_process_change_on: params[:apply_process_change_on]
    )

    # max 13 states, fine to do to_a directly
    current_machine_states = mes_machine_states.pluck(:name)
    params[:mes_machine_states_to_add].each do |machine_state|
      unless current_machine_states.include? machine_state[:name]
        mes_machine_states.build(name: machine_state[:name], online: machine_state[:online])
      end
    end
  end

  def external_attributes
    cache = MachineFetcher.machine_status(rx_data_id)
    {
      state: cache[:status],
      time: cache[:time]
    }
  end

  def online_states
    mes_machine_states.where(online: true).pluck(:name)
  end

  concerning :IsRouterResource do
    def as_router_data
      cache_data = MachineFetcher.machine_status(rx_data_id)
      base = super

      base.merge!(process_router_data)

      base.merge!(
      {
        serialNumber: sn,
        externalState: if cache_data[:status].nil?
                         {
                           state: 'OFF',
                           time: Time.zone.now - 1.month # an old time stamp ensures this machine state will always be replaced by a newer state
                         }
                       else
                         {
                            state: cache_data[:status],
                            time: cache_data[:time]
                         }
                       end,
        onlineStates: online_states_as_router_data,
        sendRejectsTo: selected_reject_as_router_data
      })
    end

    private

    def online_states_as_router_data
      mes_machine_states.where(online: true).pluck(:name)
    end

    def selected_reject_as_router_data
      return nil if selected_reject.nil?

      reject = Machine.joins(:component).where(id: selected_reject).first

      return nil if reject.nil?

      reject.name
    end
  end
end

