class OpcuaConnector < Connector
  has_many :connector_commands
  has_many :device_routing_commands, :through => :connector_commands

  def assign_attributes_from_params(params)
    has_scanner = !(params[:rx_scanner_reference].nil? && params[:opcua_scanner_reference].nil?)

    assign_attributes(
      name: params[:name],
      variable: params[:variable],
      state: params[:state],
      priority: params[:priority],
      action_delay: params[:action_delay],
      rx_scanner_reference: params[:rx_scanner_reference],
      opcua_scanner_reference: params[:opcua_scanner_reference],
      scanner_retry: has_scanner ? params[:scanner_retry] : nil,
      control_action_config: ensure_control_action_params(params[:control_action_config]),
      path_length: params[:path_length]
    )
  end

  concerning :IsRouterResource do
    def as_router_data
      connector_data = {
        name: name,
        actionDelay: action_delay,
        priorityRating: priority,
        state: state,
        pathLength: path_length,
        controlActions: if control_action_config.nil?
                          nil
                        else
                          JSON.parse(control_action_config)
                        end
      }

      unless opcua_scanner_reference.nil?
        connector_data[:scanner] = {
          maxRetryOnFail: scanner_retry,
          type: 'opcua',
          data: {
            variable: opcua_scanner_reference
          }
        }
      end

      unless rx_scanner_reference.nil?
        connector_data[:scanner] = {
          maxRetryOnFail: scanner_retry,
          type: 'external',
          data: {
            id: rx_scanner_reference
          }
        }
      end

      connector_data
    end
  end
end

