class CompleteScheduledProcessChange < RxModule::Routine
  class << self
    def frequency
      '5s'
    end

    def work
      ScheduledProcessChange.where("complete_at <= ?", Time.zone.now).find_each do |change|
        order = change.order
        machine = change.machine

        unless order.nil? || machine.nil?
          if machine.job_process.nil?
            return Rails::logger.info "Unable to finish scheduled process for order #{order.number} - source no longer has a process."
          end

          if order.required_process_started?(machine.job_process)
            Router.instance.synchronize_model(order) do
              do_delayed_process_change(order, machine)
            end
          else
            Rails::logger.info "Unable to finish scheduled process for order #{order.number} - process is no longer in started state."
          end
        end

        change.destroy!
      end
    end

    def do_delayed_process_change(order, machine)
      job_process = machine.job_process

      [order.job_for_side('right'), order.job_for_side('left')].compact.each do |job|
        required_process = job.required_processes.find_by(job_process_id: job_process.id)

        next if required_process.nil?

        apply_machine_process(machine, required_process)
      end
    end

    def apply_machine_process(machine, required_process)
      # some virtual machines still need to post to rx-data (machines created in Rx-Data then 'forced' to VM)
      if machine.sn
        required_process.validate_and_assign_state_with_history(RequiredProcess.STATE[:finished], machine.component.name, Time.zone.now, nil)
        required_process.post_current_as_job_state(machine)
      else
        required_process.validate_and_assign_state(RequiredProcess.STATE[:finished], machine.component.name, Time.zone.now, nil)
      end
      required_process.save!
    end
  end
end