Rails.application.routes.draw do
  scope :api do
    resources :devices do
      collection do
        post :bulk_create
      end
      member do
        put :reset
      end
    end
    resources :device_types
    resources :device_routing_commands
    resources :extra_requirements, only: [:create, :show, :index, :destroy]
    resources :machines do
      member do
        put :set_machine_virtual
      end
      collection do
        get "reject_stations"
        post "change_from_external"
        post "state_from_external"
        post :capability_update
      end
    end
    resources :mes_machine_states, only: [:update, :index, :show, :destroy]
    resources :capability_machines, only: [:update, :index, :show, :destroy] do
      member do
        put "toggle"
      end
    end
    resources :device_routing_command_devices, only: [:index, :show] do
      member do
        put "toggle"
      end
    end
    resources :job_processes
    resources :capabilities
    resources :routing_graphs
    resources :connectors, only: [:index, :show, :update] do
      post "/update_state" => "connectors#update_state"
    end
    resources :ignored_abort_reasons
    resources :reject_filters
    resources :components
    resources :scanners
    resources :device_timers
    resources :tags
    resources :tag_conditions
    resources :order_histories
    resources :orders do
      member do
        post :complete_up_to_process
        post :reset_down_to_process
        post :rework_up_to_process
        post :update_required_processes
        put :toggle_reject
        get :status
        post :set_order_machine_schedule
      end
      collection do
        get "search_data/:order_number" => "orders#search_data"
        get "search/:order_number" => "orders#search"
      end
    end
    resources :jobs,  only: [] do
      collection do
        get :scan, to: "customer_endpoints#lmacrodlp_scan"
      end
    end
    resources :required_processes, only: [:index] do
      member do
        post :rework_up_to
      end
    end
    resources :required_process_state_histories, only: [:show, :index]
    resources :settings
    resources :lms_configs do
      member do
        post "/reinitialize" => "lms_configs#reinitialize"
      end
    end
    resources :delayed_jobs_queue

    resources :routers, only: [:show, :index] do
      collection do
        put :start
        put :stop
      end
    end

    resources :events, only: [:show, :index]

    get "/active_record_connection_pools" => "settings#active_record_connection_pools"

    #post "machines/create_or_delete_from_external" => "machines#create_or_delete_from_external"
    post "jobs/rx_data_update" => "jobs#rx_data_update"

    post "orders/update_from_rx_net" => "orders#update_from_rx_net"
  end

  scope :router, defaults: {format: :json} do
    get "systems_status" => "routers#systems_status"
    get "refresh_machine_statuses" => "routers#refresh_machine_statuses"
    put "state" => "routers#state"
    post "event" => "routers#events"

    scope :startup do
      get "communicators" => "routers#communicators"
      get "base_settings" => "routers#base_settings"
      get "plc_settings" => "routers#plc_settings"
      get "device_definitions" => "routers#device_definitions"
      get "devices" => "routers#devices"
      get "machines" => "routers#machines"
      get "processes" => "routers#processes"
      get "routes" => "routers#routes"
      get "default_job_processes" => "routers#default_job_processes"
      get "settings" => "routers#settings"
    end


    resources :orders, only: [] do
      # Note: these methods are not member methods as it is called by the router which does not have the job id
      collection do
        post :fetch
        put :update_processes
        put :update_location
        put :update_reject
        put :complete
        put :schedule_process_state_change
        put :add_process
      end
    end


    resources :jobs, only: [] do
      # Note: these methods are not member methods as it is called by the router which does not have the job id
      collection do
        post :post_job_states_to_rx_data
      end
    end
  end

  mount RxModule::Engine => "/api/rx_module"
  root '/', controller: :index, action: :show, as: :index_show
  match '*path' => 'index#show', via: :all
end
