class FixSingleInheritanceTypeNames < ActiveRecord::Migration[6.0]
  def up
    Machine.where.not(rx_data_id: nil).update_all(type: 'MachineMes')
    Machine.where(rx_data_id: nil).update_all(type: 'MachineVirtual')

    rename_column :mes_machine_states, :mes_machine_id, :machine_mes_id

    Device.where(type: 'MesDevice').update_all(type: 'MopDevice')

    # This has to be executed as raw SQL statement as we will no longer be able to load components due to invalid type
    if Machine.count > 0
      execute("update connectors set type='MachineConnector' where component_id IN #{formatted_machine_ids}")
    end

    Connector.where(type: 'MesConnector').update_all(type: 'MopConnector')

    # Move the opcua_component_id to the device_id, as it's blocking us from removing type from component
    add_belongs_to :device_timers, :opcua_device

    Device.joins(:component).pluck(:id, :component_id).each do |timer|
      execute("update device_timers set opcua_device_id=#{timer[0]} where opcua_component_id=#{timer[1]}")
    end

    remove_belongs_to :device_timers, :opcua_component

    # The old association would leave orphan records if a device was deleted
    DeviceTimer.where(device_type_id: nil, opcua_device_id: nil).delete_all

    remove_column :components, :type
  end

  def down
    raise ActiveRecord::IrreversibleMigration
  end

  def formatted_machine_ids
    format_values_for_sql(Machine.joins(:component).pluck(:component_id))
  end

  def format_values_for_sql(ids)
    ids = ids.to_s
       .delete('[')
       .delete(']')
    "(#{ids})"
  end
end
