class CleanUpSettings < ActiveRecord::Migration[6.0]
  def up
    add_column  :settings,:loop_load_balancing_enabled, :boolean, :default => false

    change_column_default(:settings, :lms_rule_mode, 'priority_based')

    rename_column(:settings, :routing_level, :routing_level_old)
    rename_column(:settings, :connection_type, :connection_type_old)
    rename_column(:settings, :variant, :variant_old)

    add_column(:settings, :routing_level, :integer, :default => 0)
    add_column(:settings, :connection_type, :integer, :default => 0)
    add_column(:settings, :variant, :integer, :default => 0)

    ensure_legacy_settings

    remove_column(:settings, :routing_level_old)
    remove_column(:settings, :connection_type_old)
    remove_column(:settings, :variant_old)
    remove_column :settings, :load_balancing_mode
    remove_column :settings, :loop_clustering_enabled
    remove_column :settings, :route_cache_enabled
    remove_column :settings, :inf_enabled
    remove_column :settings, :inf_max_attempts
    remove_column :settings, :inf_time_between_attempts
  end

  def ensure_legacy_settings
    # Only do the following if settings already exists, do not invoke via instance

    Setting.reset_column_information

    setting = Setting.first
    return if setting.nil?

    setting.routing_level = %w(easy mes finishing).index(setting.routing_level_old.downcase)
    setting.connection_type = %w(opcua mes).index(setting.connection_type_old.downcase)
    setting.variant = %w(ncc modular flex_link).index(setting.variant_old.downcase) unless setting.variant_old.nil?

    setting.loop_load_balancing_enabled = if setting.load_balancing_mode.nil? || setting.load_balancing_mode == 'none'
                                            false
                                          else
                                            true
                                          end
    setting.save!
  end

  def down
    raise ActiveRecord::IrreversibleMigration
  end
end
