class ChangeMachineForcedStateToEnum < ActiveRecord::Migration[6.0]
  class Machine < ActiveRecord::Base
    self.inheritance_column = :_type_disabled
  end

  class VirtualMachine < Machine
  end

  class MesMachine < Machine
  end

  def state_to_int
    {
      'online' => 0,
      'offline' => 1,
      'none' => 2
    }
  end

  def int_to_state
    ['online', 'offline', 'use_state']
  end

  def up
    Machine.connection.schema_cache.clear!
    Machine.reset_column_information

    rename_column :machines, :forced_state, :old_forced_state
    add_column :machines, :forced_state, :integer

    Machine.find_each do |machine|
      if state_to_int.has_key? machine.old_forced_state
        machine.update(forced_state: state_to_int[machine.old_forced_state])
      else
        machine.update(forced_state: 0)
      end
    end

    remove_column :machines, :old_forced_state
  end

  def down
    Machine.connection.schema_cache.clear!
    Machine.reset_column_information

    rename_column :machines, :forced_state, :old_forced_state
    add_column :machines, :forced_state, :string

    Machine.find_each do |machine|
      if machine.old_forced_state.nil?
        machine.update(forced_state: nil)
      else
        machine.update(forced_state: int_to_state[machine.old_forced_state])
      end
    end

    remove_column :machines, :old_forced_state
  end
end
