class UpdateMachineSti < ActiveRecord::Migration[6.0]
  def up

    # bulk update creates a temporary table called TEMP for the postgres adapter
    # When calling bulk_update more than once, it attempts create a duplicate table and fails
    # reconnect to the connection to fix this issue
    ActiveRecord::Base.connection.reconnect!

    # Update machine type to proper STI type
    start_process = JobProcess.find_by(name: "start")
    processed_process = JobProcess.find_by(name: "processed")
    accepted_capability = Capability.find_by(name: 'accepted')
    rejected_capability = Capability.find_by(name: 'rejected')

    bulk_machine_update = []
    unless start_process.nil? || processed_process.nil? || accepted_capability.nil? || rejected_capability.nil?
      Machine.find_each do |machine|
        if machine.job_process_id == start_process.id
          bulk_machine_update << { id: machine.id, type: 'MachineStart' }
        elsif machine.job_process_id == processed_process.id
          # Legacy exits had BOTH reject and accepted, so its important we check for
          # accepted first otherwise exits are tagged as reject stations in the new model
          if machine.capability_ids.include? accepted_capability.id
            bulk_machine_update << { id: machine.id, type: 'MachineExit' }
          elsif machine.capability_ids.include? rejected_capability.id
            bulk_machine_update << { id: machine.id, type: 'MachineReject' }
          end
        end
      end
    end

    Machine.bulk_update(bulk_machine_update)
  end

  def down
    raise ActiveRecord::IrreversibleMigration
  end
end
