class ProcessFetcher
  class ProcessFetcherDisabled < StandardError; end

  def self.use_default_on_fail
    use_default = Setting.first.use_default_processes_on_fail_fetch
    return false if use_default.nil?
    use_default
  end

  # Make a synchronous request for a job's process data.
  # Note: This method only fetches the data, it's the responsibility of the caller to do something with the data
  def self.fetch_for_job_number(job_number, post_job_data = false)
    setting = Setting.instance

    if setting.rx_data_tag_source?
      return ProcessRequests::RxData.new(job_number)
    elsif setting.lms_tag_source?
      return ProcessRequests::Lms.new(job_number, post_job_data)
    else
      raise ProcessFetcherDisabled
    end
  end

  def self.default_processes_json
    requiredProcesses = JobProcessCalculator.instance.default_processes

    processes = {}

    requiredProcesses.each do |reqProcess|
      name = reqProcess[:name]

      if processes[name].nil?
        processes[name] = {
          capabilities: []
        }
      end

      processes[name][:capabilities] = processes[name][:capabilities].concat(reqProcess[:capabilities])
    end

    processes.map do |key, value|
      {
        name: key,
        capabilities: value[:capabilities].uniq
      }
    end
  end
end