namespace :jobs do
  desc "Delete ALL jobs from the database"
  task :delete_all => :environment do
    if Job.count > 0
      Job.destroy_all
      puts "Deleted all jobs"
    else
      puts "No jobs to delete"
    end
  end

  desc "Delete all INACTIVE jobs from the database"
  task :delete_all_inactive => :environment do
    if Job.count > 0
      jobs = Job.where(:active == false)
      if jobs.count > 0
        jobs.destroy_all
        puts "Deleted all inactive jobs"
      end
      puts "No jobs to delete"
    else
      puts "No jobs to delete"
    end
  end

  desc "Mapping all snake case reject_reason to camelCase reject_reasons"
  task :remap_reject_reasons => :environment do
    hash = {
        no_valid_path: 'noValidPath',
        routed_while_waiting_other_process: 'routedWhileWaitingOtherProcess',
        fail_to_scan: 'failToScan',
        fail_fetch_processes: 'failFetchProcesses',
        marked_dead: 'markedDead',
        no_processes: 'noProcesses',
        received_process_in_complete_state: 'receivedProcessInCompleteState',
        received_process_while_waiting_other_complete: 'receivedProcessWhileWaitingOtherProcessComplete',
        received_invalid_process: 'receivedInvalidProcess',
        received_start_in_reject: 'receivedStartInReject',
        no_processes_at_non_start: 'noProcessesAtNonStart',
        completed_invalid_process_in_default: 'completedInvalidProcessInDefault',
        manual_reject: 'manualReject',
        process_aborted: 'processAborted',
        failed_to_synchronize: 'rxFailedToSynchronize',
        invalid_completed_processes: 'rxInvalidCompletedProcesses'
    }.stringify_keys
    Job.transaction do
      Job.where.not(reject_reason: nil).each do |job|
        if hash.has_key?(job.reject_reason)
          job.reject_reason = hash[job.reject_reason]
          job.save
        end
      end
    end
  end
end