namespace :v3_update do
  desc "Update order_id and job_id from Rx-Data"
  task :update_order_id_and_job_id => :environment do
    # bulk update creates a temporary table called TEMP for the postgres adapter
    # When calling bulk_update more than once, it attempts create a duplicate table and fails
    # reconnect to the connection to fix this issue
    ActiveRecord::Base.connection.reconnect!

    order_data = Order.where(rx_data_order_id: nil).pluck(:id, :number)

    next if order_data.empty? # a task is similar to a block, next == return in this case

    order_id_info = RxModule::Communicator.call_module_method('rx_data', '/api/orders/order_job_ids_for_routing', :post, {
      order_numbers: order_data.map {|order_datum| order_datum[1]}
    },
    {},
      Faraday.new(
        nil,
        ssl: { verify: !RxModule::Communicator.skip_ssl_validation },
        request: { timeout: 600 }
      )
    )

    routing_data = Job.select([
        Arel::Nodes::Case.new.when(Job.arel_table[:side].eq(0)).then(Job.arel_table[:id]).else(nil).maximum.as('job_id_l'),
        Arel::Nodes::Case.new.when(Job.arel_table[:side].eq(1)).then(Job.arel_table[:id]).else(nil).maximum.as('job_id_r'),
        Order.arel_table[:number],
        Order.arel_table[:id].as('order_id')
      ])
      .where(rx_data_job_id: nil)
      .joins(Job.arel_table.join(Order.arel_table).on(
       Order.arel_table[:id].eq(Job.arel_table[:order_id])
      ).join_sources)
      .group(Order.arel_table[:id], Order.arel_table[:number])

    order_number_hash = {}
    routing_data.each { |r_data| order_number_hash[r_data[:number]] = { order_id: r_data[:order_id], job_id_r: r_data[:job_id_r], job_id_l: r_data[:job_id_l] } }

    bulk_order_update = []
    bulk_job_update = []

    order_id_info.each do |o_info|
      r_data = order_number_hash[o_info[:job_number]]
      next if r_data.nil?
      bulk_order_update << { id: r_data[:order_id], rx_data_order_id: o_info[:order_id] }
      [:job_id_l, :job_id_r].each do |job_id_side|
        bulk_job_update << { id: r_data[job_id_side], rx_data_job_id: o_info[job_id_side] } unless r_data[job_id_side].nil?
      end
    end

    Order.bulk_update(bulk_order_update)

    # bulk update creates a temporary table called TEMP for the postgres adapter
    # When calling bulk_update more than once, it attempts create a duplicate table and fails
    # reconnect to the connection to fix this issue
    ActiveRecord::Base.connection.reconnect!

    Job.bulk_update(bulk_job_update)
  end
end